@@ -20,7 +20,7 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program. If not, see <https://www.gnu.org/licenses/>.
-"""
+"""  # noqa
 from __future__ import annotations
 
 import getopt
@@ -49,9 +49,9 @@ __license__    = "GPLv3"
 __author__     = "Veronica Berglyd Olsen"
 __maintainer__ = "Veronica Berglyd Olsen"
 __email__      = "code@vkbo.net"
-__version__    = "2.7.5"
-__hexversion__ = "0x020705f0"
-__date__       = "2025-09-14"
+__version__    = "2.8.1"
+__hexversion__ = "0x020801f0"
+__date__       = "2025-12-28"
 __status__     = "Stable"
 __domain__     = "novelwriter.io"
 
@@ -206,9 +206,9 @@ def main(sysArgs: list | None = None) -> GuiMain | None:
     # Check Packages and Versions
     errorData = []
     errorCode = 0
-    if sys.hexversion < 0x030a00f0:
+    if sys.hexversion < 0x030b00f0:
         errorData.append(
-            f"At least Python 3.10 is required, found {CONFIG.verPyString}"
+            f"At least Python 3.11 is required, found {CONFIG.verPyString}"
         )
         errorCode |= 0x04
     if CONFIG.verQtValue < 0x060400:
@@ -296,7 +296,8 @@ def _createApp(style: str) -> QApplication:
     """Create the app. This is done in a function to make it easier to
     block app creation during testing.
     """
-    app = QApplication([CONFIG.appName, f"-style={style}"])
+    app = QApplication([CONFIG.appName])
+    app.setStyle(style)
     app.setApplicationName(CONFIG.appName)
     app.setApplicationVersion(__version__)
     app.setOrganizationDomain(__domain__)
