@@ -22,7 +22,7 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program. If not, see <https://www.gnu.org/licenses/>.
-"""
+"""  # noqa
 from __future__ import annotations
 
 import json
@@ -35,16 +35,18 @@ from typing import TYPE_CHECKING, Final
 
 from PyQt6.QtCore import (
     PYQT_VERSION, PYQT_VERSION_STR, QT_VERSION, QT_VERSION_STR, QDate,
-    QDateTime, QLibraryInfo, QLocale, QStandardPaths, QSysInfo, QTranslator
+    QDateTime, QLibraryInfo, QLocale, QRect, QStandardPaths, QSysInfo,
+    QTranslator
 )
 from PyQt6.QtGui import QFont, QFontDatabase, QFontMetrics
 from PyQt6.QtWidgets import QApplication
 
 from novelwriter.common import (
     NWConfigParser, checkInt, checkPath, describeFont, fontMatcher,
-    formatTimeStamp, processDialogSymbols, simplified
+    formatTimeStamp, joinLines, languageName, processDialogSymbols, simplified
 )
 from novelwriter.constants import nwFiles, nwQuotes, nwUnicode
+from novelwriter.enum import nwTheme
 from novelwriter.error import formatException, logException
 
 if TYPE_CHECKING:
@@ -55,13 +57,20 @@ if TYPE_CHECKING:
 
 logger = logging.getLogger(__name__)
 
-DEF_GUI = "default"
-DEF_SYNTAX = "default_light"
+DEF_GUI_DARK = "default_dark"
+DEF_GUI_LIGHT = "default_light"
 DEF_ICONS = "material_rounded_normal"
 DEF_TREECOL = "theme"
 
 
 class Config:
+    """User Config.
+
+    The main user config. The state of the config is stored in the
+    novelwriter.conf file between sessions. Most of the settings can be
+    modified by the user in the Preferences dialog, but some just record
+    various states of the GUI.
+    """
 
     __slots__ = (
         "_appPath", "_appRoot", "_backPath", "_backupPath", "_confPath", "_dLocale", "_dShortDate",
@@ -69,22 +78,23 @@ class Config:
         "_manuals", "_nwLangPath", "_qLocale", "_qtLangPath", "_qtTrans", "_recentPaths",
         "_recentProjects", "_splash", "allowOpenDial", "altDialogClose", "altDialogOpen",
         "appHandle", "appName", "askBeforeBackup", "askBeforeExit", "autoSaveDoc", "autoSaveProj",
-        "autoScroll", "autoScrollPos", "autoSelect", "backupOnClose", "cursorWidth", "dialogLine",
-        "dialogStyle", "doJustify", "doReplace", "doReplaceDQuote", "doReplaceDash",
+        "autoScroll", "autoScrollPos", "autoSelect", "backupOnClose", "cursorWidth", "darkTheme",
+        "dialogLine", "dialogStyle", "doJustify", "doReplace", "doReplaceDQuote", "doReplaceDash",
         "doReplaceDots", "doReplaceSQuote", "emphLabels", "fmtApostrophe", "fmtDQuoteClose",
         "fmtDQuoteOpen", "fmtPadAfter", "fmtPadBefore", "fmtPadThin", "fmtSQuoteClose",
-        "fmtSQuoteOpen", "focusWidth", "guiFont", "guiLocale", "guiSyntax", "guiTheme",
-        "hasEnchant", "hideFocusFooter", "hideHScroll", "hideVScroll", "highlightEmph", "hostName",
+        "fmtSQuoteOpen", "focusWidth", "fontWinSize", "guiFont", "guiLocale", "hasEnchant",
+        "hideFocusFooter", "hideHScroll", "hideVScroll", "highlightEmph", "hostName",
         "iconColDocs", "iconColTree", "iconTheme", "incNotesWCount", "isDebug", "kernelVer",
-        "lastNotes", "mainPanePos", "mainWinSize", "memInfo", "narratorBreak", "narratorDialog",
-        "nativeFont", "osDarwin", "osLinux", "osType", "osUnknown", "osWindows", "outlinePanePos",
-        "prefsWinSize", "scrollPastEnd", "searchCase", "searchLoop", "searchMatchCap",
-        "searchNextFile", "searchProjCase", "searchProjRegEx", "searchProjWord", "searchRegEx",
-        "searchWord", "showEditToolBar", "showFullPath", "showLineEndings", "showMultiSpaces",
-        "showSessionTime", "showTabsNSpaces", "showViewerPanel", "spellLanguage", "stopWhenIdle",
-        "tabWidth", "textFont", "textMargin", "textWidth", "useCharCount", "userIdleTime",
-        "verPyQtString", "verPyQtValue", "verPyString", "verQtString", "verQtValue",
-        "viewComments", "viewPanePos", "viewSynopsis", "welcomeWinSize",
+        "lastNotes", "lightTheme", "lineHighlight", "mainPanePos", "mainWinSize", "memInfo",
+        "moveMainWin", "narratorBreak", "narratorDialog", "nativeFont", "osDarwin", "osLinux",
+        "osType", "osUnknown", "osWindows", "outlinePanePos", "prefsWinSize", "scrollPastEnd",
+        "searchCase", "searchLoop", "searchMatchCap", "searchNextFile", "searchProjCase",
+        "searchProjRegEx", "searchProjWord", "searchRegEx", "searchWord", "showEditToolBar",
+        "showFullPath", "showLineEndings", "showMultiSpaces", "showSessionTime", "showTabsNSpaces",
+        "showViewerPanel", "spellLanguage", "stopWhenIdle", "tabWidth", "textFont", "textMargin",
+        "textWidth", "themeMode", "useCharCount", "userIdleTime", "verPyQtString", "verPyQtValue",
+        "verPyString", "verQtString", "verQtValue", "viewComments", "viewNotes", "viewPanePos",
+        "viewSynopsis", "vimMode", "welcomeWinSize",
     )
 
     LANG_NW   = 1
@@ -100,7 +110,6 @@ class Config:
         # Set Application Variables
         self.appName   = "novelWriter"
         self.appHandle = "novelwriter"
-
         # Set Paths
         confRoot = Path(QStandardPaths.writableLocation(
             QStandardPaths.StandardLocation.ConfigLocation)
@@ -153,14 +162,16 @@ class Config:
 
         # General GUI Settings
         self.guiLocale    = self._qLocale.name()
-        self.guiTheme     = DEF_GUI     # GUI theme
-        self.guiSyntax    = DEF_SYNTAX  # Syntax theme
-        self.guiFont      = QFont()     # Main GUI font
-        self.hideVScroll  = False       # Hide vertical scroll bars on main widgets
-        self.hideHScroll  = False       # Hide horizontal scroll bars on main widgets
-        self.lastNotes    = "0x0"       # The latest release notes that have been shown
-        self.nativeFont   = True        # Use native font dialog
-        self.useCharCount = False       # Use character count as primary count
+        self.lightTheme   = DEF_GUI_LIGHT  # Light GUI theme
+        self.darkTheme    = DEF_GUI_DARK   # Dark GUI theme
+        self.themeMode    = nwTheme.AUTO   # Colour theme mode
+        self.guiFont      = QFont()        # Main GUI font
+        self.hideVScroll  = False          # Hide vertical scroll bars on main widgets
+        self.hideHScroll  = False          # Hide horizontal scroll bars on main widgets
+        self.lastNotes    = "0x0"          # The latest release notes that have been shown
+        self.nativeFont   = True           # Use native font dialog
+        self.useCharCount = False          # Use character count as primary count
+        self.vimMode      = False          # Enable Vim mode
 
         # Icons
         self.iconTheme   = DEF_ICONS    # Icons theme
@@ -171,15 +182,17 @@ class Config:
         self.mainWinSize    = [1200, 650]  # Last size of the main GUI window
         self.welcomeWinSize = [800, 550]   # Last size of the welcome window
         self.prefsWinSize   = [700, 615]   # Last size of the Preferences dialog
+        self.fontWinSize    = [700, 550]   # Last size of the Font dialog
         self.mainPanePos    = [300, 800]   # Last position of the main window splitter
         self.viewPanePos    = [500, 150]   # Last position of the document viewer splitter
         self.outlinePanePos = [500, 150]   # Last position of the outline panel splitter
+        self.moveMainWin    = True         # Move main window to the screen middle on startup
 
         # Project Settings
         self.autoSaveProj    = 60     # Interval for auto-saving project, in seconds
         self.autoSaveDoc     = 30     # Interval for auto-saving document, in seconds
-        self.emphLabels      = True   # Add emphasis to H1 and H2 item labels
-        self.backupOnClose   = False  # Flag for running automatic backups
+        self.emphLabels      = False  # Add emphasis to H1 and H2 item labels
+        self.backupOnClose   = True   # Flag for running automatic backups
         self.askBeforeBackup = True   # Flag for asking before running automatic backup
         self.askBeforeExit   = True   # Flag for asking before exiting the app
 
@@ -189,6 +202,7 @@ class Config:
         self.textMargin      = 40       # Editor/viewer text margin
         self.tabWidth        = 40       # Editor tabulator width
         self.cursorWidth     = 1        # Editor cursor width
+        self.lineHighlight   = False    # Highlight current line in editor
 
         self.focusWidth      = 800      # Focus Mode text width
         self.hideFocusFooter = False    # Hide document footer in Focus Mode
@@ -198,7 +212,7 @@ class Config:
         self.doJustify       = False    # Justify text
         self.showTabsNSpaces = False    # Show tabs and spaces in editor
         self.showLineEndings = False    # Show line endings in editor
-        self.showMultiSpaces = True     # Highlight multiple spaces in the text
+        self.showMultiSpaces = False    # Highlight multiple spaces in the text
 
         self.doReplace       = True     # Enable auto-replace as you type
         self.doReplaceSQuote = True     # Smart single quotes
@@ -206,7 +220,7 @@ class Config:
         self.doReplaceDash   = True     # Replace multiple hyphens with dashes
         self.doReplaceDots   = True     # Replace three dots with ellipsis
 
-        self.autoScroll      = False    # Typewriter-like scrolling
+        self.autoScroll      = True     # Typewriter-like scrolling
         self.autoScrollPos   = 30       # Start point for typewriter-like scrolling
         self.scrollPastEnd   = True     # Scroll past end of document, and centre cursor
 
@@ -245,6 +259,7 @@ class Config:
         self.showSessionTime = True   # Show the session time in the status bar
         self.viewComments    = True   # Comments are shown in the viewer
         self.viewSynopsis    = True   # Synopsis is shown in the viewer
+        self.viewNotes       = True   # Notes are shown in the viewer
 
         # Search Box States
         self.searchCase      = False
@@ -295,8 +310,6 @@ class Config:
         # Packages
         self.hasEnchant = False  # The pyenchant package
 
-        return
-
     ##
     #  Properties
     ##
@@ -345,29 +358,31 @@ class Config:
     def setLastAuthor(self, value: str) -> None:
         """Set tle last used author name."""
         self._lastAuthor = simplified(value)
-        return
 
-    def setMainWinSize(self, width: int, height: int) -> None:
+    def setMainWinSize(self, geometry: QRect) -> None:
         """Set the size of the main window, but only if the change is
         larger than 5 pixels. The OS window manager will sometimes
         adjust it a bit, and we don't want the main window to shrink or
         grow each time the app is opened.
         """
+        width = geometry.width()
+        height = geometry.height()
         if abs(self.mainWinSize[0] - width) > 5:
             self.mainWinSize[0] = width
         if abs(self.mainWinSize[1] - height) > 5:
             self.mainWinSize[1] = height
-        return
 
-    def setWelcomeWinSize(self, width: int, height: int) -> None:
+    def setWelcomeWinSize(self, geometry: QRect) -> None:
         """Set the size of the Preferences dialog window."""
-        self.welcomeWinSize = [width, height]
-        return
+        self.welcomeWinSize = [geometry.width(), geometry.height()]
 
-    def setPreferencesWinSize(self, width: int, height: int) -> None:
+    def setPreferencesWinSize(self, geometry: QRect) -> None:
         """Set the size of the Preferences dialog window."""
-        self.prefsWinSize = [width, height]
-        return
+        self.prefsWinSize = [geometry.width(), geometry.height()]
+
+    def setFontWinSize(self, geometry: QRect) -> None:
+        """Set the size of the Font dialog window."""
+        self.fontWinSize = [geometry.width(), geometry.height()]
 
     def setLastPath(self, key: str, path: str | Path) -> None:
         """Set the last used path. Only the folder is saved, so if the
@@ -379,12 +394,10 @@ class Config:
                 path = path.parent
             if path.is_dir():
                 self._recentPaths.setPath(key, path)
-        return
 
     def setBackupPath(self, path: Path | str) -> None:
         """Set the current backup path."""
         self._backupPath = checkPath(path, self._backPath)
-        return
 
     def setGuiFont(self, value: QFont | str | None) -> None:
         """Update the GUI's font style from settings."""
@@ -403,9 +416,8 @@ class Config:
             else:
                 font = QFontDatabase.systemFont(QFontDatabase.SystemFont.GeneralFont)
             self.guiFont = fontMatcher(font)
-            logger.debug("GUI font set to: %s", describeFont(font))
+            logger.debug("Main font set to: %s", describeFont(font))
         QApplication.setFont(self.guiFont)
-        return
 
     def setTextFont(self, value: QFont | str | None) -> None:
         """Set the text font if it exists. If it doesn't, or is None,
@@ -431,14 +443,13 @@ class Config:
                 font = QFontDatabase.systemFont(QFontDatabase.SystemFont.GeneralFont)
             self.textFont = fontMatcher(font)
             logger.debug("Text font set to: %s", describeFont(self.textFont))
-        return
 
     ##
     #  Methods
     ##
 
     def homePath(self) -> Path:
-        """The user's home folder."""
+        """Return the user's home folder."""
         return self._homePath
 
     def dataPath(self, target: str | None = None) -> Path:
@@ -471,7 +482,7 @@ class Config:
         """Compile and return error messages from the initialisation of
         the Config class, and clear the error buffer.
         """
-        message = "<br>".join(self._errData)
+        message = joinLines(self._errData, "<br>")
         self._hasError = False
         self._errData = []
         return message
@@ -496,11 +507,11 @@ class Config:
         if lngSet == self.LANG_NW:
             fPre = "nw_"
             fExt = ".qm"
-            langList = {"en_GB": QLocale("en_GB").nativeLanguageName().title()}
+            langList = {"en_GB": languageName("en_GB")}
         elif lngSet == self.LANG_PROJ:
             fPre = "project_"
             fExt = ".json"
-            langList = {"en_GB": QLocale("en_GB").nativeLanguageName().title()}
+            langList = {"en_GB": languageName("en_GB")}
         else:
             return []
 
@@ -510,7 +521,7 @@ class Config:
                 continue
 
             qmLang = qmName[len(fPre):-len(fExt)]
-            qmName = QLocale(qmLang).nativeLanguageName().title()
+            qmName = languageName(qmLang)
             if qmLang and qmName and qmLang != "en_GB":
                 langList[qmLang] = qmName
 
@@ -520,7 +531,6 @@ class Config:
         """Send a message to the splash screen."""
         if self._splash:
             self._splash.showStatus(message)
-        return
 
     ##
     #  Config Actions
@@ -551,11 +561,10 @@ class Config:
         self._confPath.mkdir(exist_ok=True)
         self._dataPath.mkdir(exist_ok=True)
 
-        # Also create the syntax, themes and icons folders if possible
+        # Also create the themes and icons folders if possible
         if self._dataPath.is_dir():
             (self._dataPath / "cache").mkdir(exist_ok=True)
             (self._dataPath / "icons").mkdir(exist_ok=True)
-            (self._dataPath / "syntax").mkdir(exist_ok=True)
             (self._dataPath / "themes").mkdir(exist_ok=True)
 
         self._recentPaths.loadCache()
@@ -564,8 +573,6 @@ class Config:
 
         logger.debug("Config instance initialised")
 
-        return
-
     def initLocalisation(self, nwApp: QApplication) -> None:
         """Initialise the localisation of the GUI."""
         self.splashMessage("Loading localisation ...")
@@ -593,8 +600,6 @@ class Config:
                         nwApp.installTranslator(qTrans)
                         self._qtTrans[lngFile] = qTrans
 
-        return
-
     def loadConfig(self, splash: NSplashScreen | None = None) -> bool:
         """Load preferences from file and replace default settings."""
         self._splash = splash
@@ -626,8 +631,9 @@ class Config:
         # Main
         sec = "Main"
         self.setGuiFont(conf.rdStr(sec, "font", ""))
-        self.guiTheme     = conf.rdStr(sec, "theme", self.guiTheme)
-        self.guiSyntax    = conf.rdStr(sec, "syntax", self.guiSyntax)
+        self.lightTheme   = conf.rdStr(sec, "lighttheme", self.lightTheme)
+        self.darkTheme    = conf.rdStr(sec, "darktheme", self.darkTheme)
+        self.themeMode    = conf.rdEnum(sec, "thememode", self.themeMode)
         self.iconTheme    = conf.rdStr(sec, "icons", self.iconTheme)
         self.iconColTree  = conf.rdStr(sec, "iconcoltree", self.iconColTree)
         self.iconColDocs  = conf.rdBool(sec, "iconcoldocs", self.iconColDocs)
@@ -637,15 +643,18 @@ class Config:
         self.lastNotes    = conf.rdStr(sec, "lastnotes", self.lastNotes)
         self.nativeFont   = conf.rdBool(sec, "nativefont", self.nativeFont)
         self.useCharCount = conf.rdBool(sec, "usecharcount", self.useCharCount)
+        self.vimMode      = conf.rdBool(sec, "vimmode", self.vimMode)
 
         # Sizes
         sec = "Sizes"
         self.mainWinSize    = conf.rdIntList(sec, "mainwindow", self.mainWinSize)
         self.welcomeWinSize = conf.rdIntList(sec, "welcome", self.welcomeWinSize)
         self.prefsWinSize   = conf.rdIntList(sec, "preferences", self.prefsWinSize)
+        self.fontWinSize    = conf.rdIntList(sec, "fontselect", self.fontWinSize)
         self.mainPanePos    = conf.rdIntList(sec, "mainpane", self.mainPanePos)
         self.viewPanePos    = conf.rdIntList(sec, "viewpane", self.viewPanePos)
         self.outlinePanePos = conf.rdIntList(sec, "outlinepane", self.outlinePanePos)
+        self.moveMainWin    = conf.rdBool(sec, "movemainwin", self.moveMainWin)
 
         # Project
         sec = "Project"
@@ -665,6 +674,7 @@ class Config:
         self.textMargin      = conf.rdInt(sec, "margin", self.textMargin)
         self.tabWidth        = conf.rdInt(sec, "tabwidth", self.tabWidth)
         self.cursorWidth     = conf.rdInt(sec, "cursorwidth", self.cursorWidth)
+        self.lineHighlight   = conf.rdBool(sec, "linehighlight", self.lineHighlight)
         self.focusWidth      = conf.rdInt(sec, "focuswidth", self.focusWidth)
         self.hideFocusFooter = conf.rdBool(sec, "hidefocusfooter", self.hideFocusFooter)
         self.doJustify       = conf.rdBool(sec, "justify", self.doJustify)
@@ -708,6 +718,7 @@ class Config:
         self.showSessionTime = conf.rdBool(sec, "showsessiontime", self.showSessionTime)
         self.viewComments    = conf.rdBool(sec, "viewcomments", self.viewComments)
         self.viewSynopsis    = conf.rdBool(sec, "viewsynopsis", self.viewSynopsis)
+        self.viewNotes       = conf.rdBool(sec, "viewnotes", self.viewNotes)
         self.searchCase      = conf.rdBool(sec, "searchcase", self.searchCase)
         self.searchWord      = conf.rdBool(sec, "searchword", self.searchWord)
         self.searchRegEx     = conf.rdBool(sec, "searchregex", self.searchRegEx)
@@ -721,7 +732,7 @@ class Config:
         # Check Values
         # ============
 
-        self._prepareFont(self.guiFont, "GUI")
+        self._prepareFont(self.guiFont, "main")
         self._prepareFont(self.textFont, "document")
 
         # If we're using straight quotes, disable auto-replace
@@ -751,8 +762,9 @@ class Config:
 
         conf["Main"] = {
             "font":         self.guiFont.toString(),
-            "theme":        str(self.guiTheme),
-            "syntax":       str(self.guiSyntax),
+            "lighttheme":   str(self.lightTheme),
+            "darktheme":    str(self.darkTheme),
+            "thememode":    self.themeMode.name,
             "icons":        str(self.iconTheme),
             "iconcoltree":  str(self.iconColTree),
             "iconcoldocs":  str(self.iconColDocs),
@@ -762,15 +774,18 @@ class Config:
             "lastnotes":    str(self.lastNotes),
             "nativefont":   str(self.nativeFont),
             "usecharcount": str(self.useCharCount),
+            "vimmode":      str(self.vimMode),
         }
 
         conf["Sizes"] = {
             "mainwindow":  self._packList(self.mainWinSize),
             "welcome":     self._packList(self.welcomeWinSize),
             "preferences": self._packList(self.prefsWinSize),
+            "fontselect":  self._packList(self.fontWinSize),
             "mainpane":    self._packList(self.mainPanePos),
             "viewpane":    self._packList(self.viewPanePos),
             "outlinepane": self._packList(self.outlinePanePos),
+            "movemainwin": str(self.moveMainWin),
         }
 
         conf["Project"] = {
@@ -790,6 +805,7 @@ class Config:
             "margin":          str(self.textMargin),
             "tabwidth":        str(self.tabWidth),
             "cursorwidth":     str(self.cursorWidth),
+            "lineHighlight":   str(self.lineHighlight),
             "focuswidth":      str(self.focusWidth),
             "hidefocusfooter": str(self.hideFocusFooter),
             "justify":         str(self.doJustify),
@@ -833,6 +849,7 @@ class Config:
             "showsessiontime": str(self.showSessionTime),
             "viewcomments":    str(self.viewComments),
             "viewsynopsis":    str(self.viewSynopsis),
+            "viewnotes":       str(self.viewNotes),
             "searchcase":      str(self.searchCase),
             "searchword":      str(self.searchWord),
             "searchregex":     str(self.searchRegEx),
@@ -862,7 +879,6 @@ class Config:
     def finishStartup(self) -> None:
         """Call after startup is complete."""
         self._splash = None
-        return
 
     ##
     #  Internal Functions
@@ -884,7 +900,6 @@ class Config:
         else:
             self.hasEnchant = True
             logger.debug("Checking package 'pyenchant': OK")
-        return
 
     def _prepareFont(self, font: QFont, kind: str) -> None:
         """Check Unicode availability in font. This also initialises any
@@ -895,16 +910,15 @@ class Config:
         for char in nwUnicode.UI_SYMBOLS:
             if not metrics.inFont(char):  # type: ignore
                 logger.warning("No glyph U+%04x in font", ord(char))  # pragma: no cover
-        return
 
 
 class RecentProjects:
+    """A record of recently opened projects."""
 
     def __init__(self, config: Config) -> None:
         self._conf = config
         self._data: dict[str, dict[str, str | int]] = {}
         self._map: dict[str, str] = {}
-        return
 
     def loadCache(self) -> bool:
         """Load the cache file for recent projects."""
@@ -966,14 +980,12 @@ class RecentProjects:
             self.saveCache()
         except Exception:
             pass
-        return
 
     def remove(self, path: str | Path) -> None:
         """Try to remove a path from the recent projects cache."""
         if self._data.pop(str(path), None) is not None:
             logger.debug("Removed recent: %s", path)
             self.saveCache()
-        return
 
     def _setEntry(
         self, puuid: str, path: str, title: str, words: int, chars: int, saved: int
@@ -988,24 +1000,22 @@ class RecentProjects:
         }
         if puuid:
             self._map[puuid] = path
-        return
 
 
 class RecentPaths:
+    """A record of recently used file paths."""
 
     KEYS: Final[list[str]] = ["default", "project", "import", "outline", "stats"]
 
     def __init__(self, config: Config) -> None:
         self._conf = config
         self._data = {}
-        return
 
     def setPath(self, key: str, path: Path | str) -> None:
         """Set a path for a given key, and save the cache."""
         if key in self.KEYS:
             self._data[key] = str(path)
         self.saveCache()
-        return
 
     def getPath(self, key: str) -> str | None:
         """Get a path for a given key, or return None."""
