@@ -20,7 +20,7 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program. If not, see <https://www.gnu.org/licenses/>.
-"""
+"""  # noqa
 from __future__ import annotations
 
 import json
@@ -57,6 +57,7 @@ logger = logging.getLogger(__name__)
 
 
 class NWProjectState(Enum):
+    """The state of the loaded project."""
 
     UNKNOWN  = 0
     LOCKED   = 1
@@ -65,6 +66,11 @@ class NWProjectState(Enum):
 
 
 class NWProject:
+    """Core: novelWriter Project Class.
+
+    This class is the parent class of the project, and holds instances
+    of project data, the project tree, and the project index.
+    """
 
     __slots__ = (
         "_changed", "_data", "_index", "_langData", "_options", "_session",
@@ -92,17 +98,13 @@ class NWProject:
 
         logger.debug("Ready: NWProject")
 
-        return
-
     def __del__(self) -> None:  # pragma: no cover
         logger.debug("Delete: NWProject")
-        return
 
     def clear(self) -> None:
         """Clear the project."""
         self._tree.clear()
         self._index.clear()
-        return
 
     ##
     #  Properties
@@ -224,7 +226,7 @@ class NWProject:
 
         return True
 
-    def copyFileContent(self, tHandle: str, sHandle: str) -> bool:
+    def copyFileContent(self, tHandle: str, sHandle: str, newTitle: str | None = None) -> bool:
         """Copy content to a new document after it is created. This
         will not run if the file exists and is not empty.
         """
@@ -239,6 +241,14 @@ class NWProject:
 
         logger.debug("Populating '%s' with text from '%s'", tHandle, sHandle)
         text = self._storage.getDocumentText(sHandle)
+        if (
+            newTitle and (lines := text.split("\n")) and lines
+            and lines[0].startswith(("# ", "## ", "### ", "#### ", "#! ", "##! ", "###! "))
+        ):
+            prefix, _, _ = lines[0].partition(" ")
+            lines[0] = f"{prefix} {newTitle}"
+            text = "\n".join(lines)
+
         self._storage.getDocument(tHandle).writeDocument(text)
         sItem.setLayout(tItem.itemLayout)
         self._index.reIndexHandle(tHandle)
@@ -255,7 +265,6 @@ class NWProject:
             if rHandle and (tHandle := SHARED.project.newFile(tag.title(), rHandle)):
                 self.writeNewFile(tHandle, 1, False, f"@tag: {tag}\n\n")
                 self._tree.refreshItems([tHandle])
-        return
 
     ##
     #  Project Methods
@@ -433,7 +442,6 @@ class NWProject:
         self._tree.writeToCFile()
         self._session.appendSession(idleTime)
         self._storage.closeSession()
-        return
 
     def backupProject(self, doNotify: bool) -> bool:
         """Create a zip file of the entire project."""
@@ -483,15 +491,14 @@ class NWProject:
 
     def setDefaultStatusImport(self) -> None:
         """Set the default status and importance values."""
-        self._data.itemStatus.add(None, self.tr("New"),      (120, 120, 120), "STAR", 0)
-        self._data.itemStatus.add(None, self.tr("Note"),     (205, 171, 143), "TRIANGLE", 0)
-        self._data.itemStatus.add(None, self.tr("Draft"),    (143, 240, 164), "CIRCLE_T", 0)
-        self._data.itemStatus.add(None, self.tr("Finished"), (249, 240, 107), "STAR", 0)
-        self._data.itemImport.add(None, self.tr("New"),      (120, 120, 120), "SQUARE", 0)
-        self._data.itemImport.add(None, self.tr("Minor"),    (220, 138, 221), "BLOCK_2", 0)
-        self._data.itemImport.add(None, self.tr("Major"),    (220, 138, 221), "BLOCK_3", 0)
-        self._data.itemImport.add(None, self.tr("Main"),     (220, 138, 221), "BLOCK_4", 0)
-        return
+        self._data.itemStatus.add(None, self.tr("New"), "faded", "STAR", 0)
+        self._data.itemStatus.add(None, self.tr("Note"), "red", "TRIANGLE", 0)
+        self._data.itemStatus.add(None, self.tr("Draft"), "yellow", "CIRCLE_T", 0)
+        self._data.itemStatus.add(None, self.tr("Finished"), "green", "STAR", 0)
+        self._data.itemImport.add(None, self.tr("New"), "purple", "SQUARE", 0)
+        self._data.itemImport.add(None, self.tr("Minor"), "purple", "BLOCK_2", 0)
+        self._data.itemImport.add(None, self.tr("Major"), "purple", "BLOCK_3", 0)
+        self._data.itemImport.add(None, self.tr("Main"), "purple", "BLOCK_4", 0)
 
     def setProjectLang(self, language: str | None) -> None:
         """Set the project-specific language."""
@@ -500,7 +507,6 @@ class NWProject:
             self._data.setLanguage(language)
             self._loadProjectLocalisation()
             self.setProjectChanged(True)
-        return
 
     def setProjectChanged(self, status: bool) -> bool:
         """Toggle the project changed flag, and propagate the
@@ -519,7 +525,6 @@ class NWProject:
         """Update the total word and character count values."""
         wNovel, wNotes, cNovel, cNotes = self._tree.sumCounts()
         self._data.setCurrCounts(wNovel=wNovel, wNotes=wNotes, cNovel=cNovel, cNotes=cNotes)
-        return
 
     def countStatus(self) -> None:
         """Count how many times the various status flags are used in the
@@ -533,7 +538,6 @@ class NWProject:
                 self._data.itemStatus.increment(nwItem.itemStatus)
             else:
                 self._data.itemImport.increment(nwItem.itemImport)
-        return
 
     def updateStatus(self, kind: T_StatusKind, update: T_UpdateEntry) -> None:
         """Update status or import entries."""
@@ -545,7 +549,13 @@ class NWProject:
             self._data.itemImport.update(update)
             SHARED.emitStatusLabelsChanged(self, kind)
             self._tree.refreshAllItems()
-        return
+
+    def updateTheme(self) -> None:
+        """Update theme elements."""
+        logger.debug("Theme Update: NWProject")
+
+        self._data.itemStatus.refreshIcons()
+        self._data.itemImport.refreshIcons()
 
     def localLookup(self, word: str | int) -> str:
         """Look up a word or number in the translation map for the
