@@ -24,22 +24,23 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program. If not, see <https://www.gnu.org/licenses/>.
-"""
+"""  # noqa
 from __future__ import annotations
 
-from PyQt6.QtGui import QColor, QFont, QPalette, QPixmap
+from PyQt6.QtGui import QColor, QFont, QPalette
 from PyQt6.QtWidgets import (
     QAbstractButton, QFrame, QHBoxLayout, QLabel, QLayout, QScrollArea,
     QVBoxLayout, QWidget
 )
 
+from novelwriter.enum import nwState
 from novelwriter.types import QtScrollAsNeeded
 
 DEFAULT_SCALE = 0.9
 
 
 class NFixedPage(QFrame):
-    """Extension: Fixed Page Widget
+    """Extension: Fixed Page Widget.
 
     A custom widget that holds a layout. This is just a wrapper around a
     QFrame that sets the same frame style as the other Page widgets.
@@ -49,23 +50,20 @@ class NFixedPage(QFrame):
         super().__init__(parent=parent)
         self.setFrameShadow(QFrame.Shadow.Sunken)
         self.setFrameShape(QFrame.Shape.StyledPanel)
-        return
 
     def setCentralLayout(self, layout: QLayout) -> None:
         """Set a layout as the central object."""
         self.setLayout(layout)
-        return
 
     def setCentralWidget(self, widget: QWidget) -> None:
         """Set a layout as the central object."""
         layout = QHBoxLayout()
         layout.addWidget(widget)
         self.setLayout(layout)
-        return
 
 
 class NScrollablePage(QScrollArea):
-    """Extension: Scrollable Page Widget
+    """Extension: Scrollable Page Widget.
 
     A custom widget that holds a layout within a scrollable area.
     """
@@ -79,16 +77,14 @@ class NScrollablePage(QScrollArea):
         self.setVerticalScrollBarPolicy(QtScrollAsNeeded)
         self.setFrameShadow(QFrame.Shadow.Sunken)
         self.setFrameShape(QFrame.Shape.StyledPanel)
-        return
 
     def setCentralLayout(self, layout: QLayout) -> None:
         """Set the central layout of the scroll page."""
         self._widget.setLayout(layout)
-        return
 
 
 class NScrollableForm(QScrollArea):
-    """Extension: Scrollable Form Widget
+    """Extension: Scrollable Form Widget.
 
     A custom widget that creates a form within a scrollable area.
     """
@@ -117,8 +113,6 @@ class NScrollableForm(QScrollArea):
         self.setFrameShadow(QFrame.Shadow.Sunken)
         self.setFrameShape(QFrame.Shape.StyledPanel)
 
-        return
-
     ##
     #  Properties
     ##
@@ -135,18 +129,15 @@ class NScrollableForm(QScrollArea):
         """Set the text color for the help text."""
         self._helpCol = color
         self._fontScale = scale
-        return
 
     def setHelpText(self, key: str, text: str) -> None:
         """Set the text for the help label."""
         if qHelp := self._editable.get(key):
             qHelp.setText(text)
-        return
 
     def setRowIndent(self, indent: int) -> None:
         """Set the indentation of each row."""
         self._indent = max(indent, 0)
-        return
 
     ##
     #  Methods
@@ -158,7 +149,6 @@ class NScrollableForm(QScrollArea):
             yPos = self._sections[identifier].pos().y() - 8
             if vBar := self.verticalScrollBar():
                 vBar.setValue(yPos)
-        return
 
     def scrollToLabel(self, label: str) -> None:
         """Scroll to the requested label."""
@@ -166,7 +156,6 @@ class NScrollableForm(QScrollArea):
             yPos = self._index[label].pos().y() - 8
             if vBar := self.verticalScrollBar():
                 vBar.setValue(yPos)
-        return
 
     def addGroupLabel(self, label: str, identifier: int | None = None) -> None:
         """Add a text label to separate groups of settings."""
@@ -178,12 +167,11 @@ class NScrollableForm(QScrollArea):
         self._first = False
         if identifier is not None:
             self._sections[identifier] = qLabel
-        return
 
     def addRow(
         self,
         label: str | None,
-        widget: QWidget | list[QWidget | QPixmap | int],
+        widget: QWidget | list[QWidget | int],
         helpText: str = "",
         unit: str | None = None,
         button: QWidget | None = None,
@@ -200,10 +188,6 @@ class NScrollableForm(QScrollArea):
             for item in widget:
                 if isinstance(item, QWidget):
                     wBox.addWidget(item)
-                elif isinstance(item, QPixmap):
-                    icon = QLabel(self)
-                    icon.setPixmap(item)
-                    wBox.addWidget(icon)
                 elif isinstance(item, int):
                     wBox.addSpacing(item)
             qWidget = QWidget(self)
@@ -252,17 +236,14 @@ class NScrollableForm(QScrollArea):
             self._index[label.strip()] = qWidget
         qLabel.setAccessibleName(text)
 
-        return
-
     def finalise(self) -> None:
         """Finalise the layout when the form is built."""
         self._layout.addSpacing(20)
         self._layout.addStretch(1)
-        return
 
 
 class NColorLabel(QLabel):
-    """Extension: A Coloured Label
+    """Extension: A Coloured Label.
 
     A custom widget that draws a label in a specific colour, and
     optionally at a specific size, and word wrapped.
@@ -275,7 +256,7 @@ class NColorLabel(QLabel):
 
     def __init__(
         self, text: str, parent: QWidget, *,
-        color: QColor | None = None, faded: QColor | None = None,
+        color: QColor | None = None, faded: QColor | None = None, error: QColor | None = None,
         scale: float = HELP_SCALE, wrap: bool = False, indent: int = 0,
         bold: bool = False
     ) -> None:
@@ -284,6 +265,7 @@ class NColorLabel(QLabel):
         default = self.palette().windowText().color()
         self._color = color or default
         self._faded = faded or default
+        self._error = error or default
 
         font = self.font()
         font.setPointSizeF(scale*font.pointSizeF())
@@ -296,37 +278,39 @@ class NColorLabel(QLabel):
         self.setFont(font)
         self.setIndent(indent)
         self.setWordWrap(wrap)
-        self.setColorState(True)
+        self.setColorState(nwState.NORMAL)
 
-        return
-
-    def setTextColors(self, *, color: QColor | None = None, faded: QColor | None = None) -> None:
+    def setTextColors(
+        self, *, color: QColor | None = None,
+        faded: QColor | None = None, error: QColor | None = None
+    ) -> None:
         """Set or update the text colours."""
         self._color = color or self._color
         self._faded = faded or self._faded
+        self._error = error or self._error
         self._refeshTextColor()
-        return
 
-    def setColorState(self, state: bool) -> None:
+    def setColorState(self, state: nwState) -> None:
         """Change the colour state."""
         if self._state is not state:
             self._state = state
             self._refeshTextColor()
-        return
 
     def _refeshTextColor(self) -> None:
         """Refresh the colour of the text on the label."""
         palette = self.palette()
-        palette.setColor(
-            QPalette.ColorRole.WindowText,
-            self._color if self._state else self._faded,
-        )
+        match self._state:
+            case nwState.NORMAL:
+                palette.setColor(QPalette.ColorRole.WindowText, self._color)
+            case nwState.INACTIVE:
+                palette.setColor(QPalette.ColorRole.WindowText, self._faded)
+            case nwState.ERROR:
+                palette.setColor(QPalette.ColorRole.WindowText, self._error)
         self.setPalette(palette)
-        return
 
 
 class NWrappedWidgetBox(QHBoxLayout):
-    """Extension: A Text-Wrapped Widget Box
+    """Extension: A Text-Wrapped Widget Box.
 
     A custom layout box where a widget is wrapped in text labels on
     either side within a layout box. The widget is inserted at the {0}
@@ -341,4 +325,3 @@ class NWrappedWidgetBox(QHBoxLayout):
         self.addWidget(widget)
         if after:
             self.addWidget(QLabel(after.lstrip()))
-        return
