@@ -20,23 +20,30 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program. If not, see <https://www.gnu.org/licenses/>.
-"""
+"""  # noqa
 from __future__ import annotations
 
 import logging
 
+from typing import TYPE_CHECKING
+
 from PyQt6.QtCore import pyqtSignal, pyqtSlot
 from PyQt6.QtGui import QPalette
-from PyQt6.QtWidgets import QComboBox, QWidget
+from PyQt6.QtWidgets import QComboBox
 
 from novelwriter import SHARED
 from novelwriter.constants import nwLabels
 from novelwriter.enum import nwItemClass
+from novelwriter.types import QtColDisabled
+
+if TYPE_CHECKING:
+    from PyQt6.QtWidgets import QWidget
 
 logger = logging.getLogger(__name__)
 
 
 class NovelSelector(QComboBox):
+    """Custom: Novel Root Folder Selector."""
 
     novelSelectionChanged = pyqtSignal(str)
 
@@ -48,7 +55,6 @@ class NovelSelector(QComboBox):
         self._listFormat = None
         self.currentIndexChanged.connect(self._indexChanged)
         self.updateTheme()
-        return
 
     ##
     #  Properties
@@ -75,26 +81,24 @@ class NovelSelector(QComboBox):
             self._blockSignal = blockSignal
             self.setCurrentIndex(index)
             self._blockSignal = False
-        return
 
     def setIncludeAll(self, value: bool) -> None:
         """Set flag to add an "All Novel Folders" option."""
         self._includeAll = value
-        return
 
     def setListFormat(self, value: str | None) -> None:
         """Set a format string for the list entries."""
         if value is None or "{0}" in value:
             self._listFormat = value
-        return
 
     def updateTheme(self) -> None:
         """Update theme colours."""
         palette = self.palette()
-        palette.setBrush(QPalette.ColorGroup.Disabled, QPalette.ColorRole.Text, palette.text())
+        palette.setBrush(QtColDisabled, QPalette.ColorRole.Text, palette.text())
+        palette.setBrush(QtColDisabled, QPalette.ColorRole.WindowText, palette.windowText())
+        palette.setBrush(QtColDisabled, QPalette.ColorRole.ButtonText, palette.buttonText())
         self.setPalette(palette)
         self.refreshNovelList()
-        return
 
     ##
     #  Public Slots
@@ -109,7 +113,7 @@ class NovelSelector(QComboBox):
         self._firstHandle = None
         self.clear()
 
-        icon = SHARED.theme.getIcon(nwLabels.CLASS_ICON[nwItemClass.NOVEL], "blue")
+        icon = SHARED.theme.getIcon(nwLabels.CLASS_ICON[nwItemClass.NOVEL], "root")
         for tHandle, nwItem in SHARED.project.tree.iterRoots(nwItemClass.NOVEL):
             if self._listFormat:
                 name = self._listFormat.format(nwItem.itemName)
@@ -128,8 +132,6 @@ class NovelSelector(QComboBox):
         self.setEnabled(self.count() > 1)
         self._blockSignal = False
 
-        return
-
     ##
     #  Private Slots
     ##
@@ -139,4 +141,3 @@ class NovelSelector(QComboBox):
         """Re-emit the change of selection signal, unless blocked."""
         if not self._blockSignal:
             self.novelSelectionChanged.emit(self.currentData())
-        return
