@@ -23,7 +23,7 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program. If not, see <https://www.gnu.org/licenses/>.
-"""
+"""  # noqa
 from __future__ import annotations
 
 import logging
@@ -43,7 +43,7 @@ from PyQt6.QtWidgets import (
 from novelwriter import CONFIG, SHARED
 from novelwriter.common import decodeMimeHandles, qtAddAction, qtLambda
 from novelwriter.constants import nwConst, nwStyles, nwUnicode
-from novelwriter.enum import nwChange, nwComment, nwDocAction, nwDocMode, nwItemType
+from novelwriter.enum import nwChange, nwComment, nwDocAction, nwDocMode, nwItemType, nwState
 from novelwriter.error import logException
 from novelwriter.extensions.configlayout import NColorLabel
 from novelwriter.extensions.eventfilters import WheelEventFilter
@@ -53,13 +53,15 @@ from novelwriter.formats.toqdoc import ToQTextDocument
 from novelwriter.gui.theme import STYLES_MIN_TOOLBUTTON
 from novelwriter.types import (
     QtAlignCenterTop, QtKeepAnchor, QtMouseLeft, QtMoveAnchor,
-    QtScrollAlwaysOff, QtScrollAsNeeded
+    QtScrollAlwaysOff, QtScrollAsNeeded, QtSelectBlock, QtSelectDocument,
+    QtSelectWord
 )
 
 logger = logging.getLogger(__name__)
 
 
 class GuiDocViewer(QTextBrowser):
+    """GUI: Document Viewer."""
 
     closeDocumentRequest = pyqtSignal()
     documentLoaded = pyqtSignal(str)
@@ -110,8 +112,6 @@ class GuiDocViewer(QTextBrowser):
 
         logger.debug("Ready: GuiDocViewer")
 
-        return
-
     ##
     #  Properties
     ##
@@ -138,13 +138,12 @@ class GuiDocViewer(QTextBrowser):
         self.setSearchPaths([""])
         self._docHandle = None
         self.docHeader.clearHeader()
-        return
 
     def updateTheme(self) -> None:
         """Update theme elements."""
+        logger.debug("Theme Update: GuiDocViewer")
         self.docHeader.updateTheme()
         self.docFooter.updateTheme()
-        return
 
     def initViewer(self) -> None:
         """Set editor settings from main config."""
@@ -206,8 +205,6 @@ class GuiDocViewer(QTextBrowser):
         # If we have a document open, we should reload it in case the font changed
         self.reloadText()
 
-        return
-
     def loadText(self, tHandle: str, updateHistory: bool = True) -> bool:
         """Load text into the viewer from an item handle."""
         if not SHARED.project.tree.checkType(tHandle, nwItemType.FILE):
@@ -228,11 +225,11 @@ class GuiDocViewer(QTextBrowser):
         qDoc.setTheme(self._docTheme)
         qDoc.initDocument()
         qDoc.setKeywords(True)
-        qDoc.setCommentType(nwComment.NOTE, CONFIG.viewComments)
-        qDoc.setCommentType(nwComment.STORY, CONFIG.viewComments)
         qDoc.setCommentType(nwComment.PLAIN, CONFIG.viewComments)
         qDoc.setCommentType(nwComment.SYNOPSIS, CONFIG.viewSynopsis)
         qDoc.setCommentType(nwComment.SHORT, CONFIG.viewSynopsis)
+        qDoc.setCommentType(nwComment.STORY, CONFIG.viewNotes)
+        qDoc.setCommentType(nwComment.NOTE, CONFIG.viewNotes)
 
         # Be extra careful here to prevent crashes when first opening a
         # project as a crash here leaves no way of recovering.
@@ -280,7 +277,6 @@ class GuiDocViewer(QTextBrowser):
         """Reload the text in the current document."""
         if self._docHandle:
             self.loadText(self._docHandle, updateHistory=False)
-        return
 
     def docAction(self, action: nwDocAction) -> bool:
         """Process document actions on the current document."""
@@ -293,11 +289,11 @@ class GuiDocViewer(QTextBrowser):
         elif action == nwDocAction.COPY:
             self.copy()
         elif action == nwDocAction.SEL_ALL:
-            self._makeSelection(QTextCursor.SelectionType.Document)
+            self._makeSelection(QtSelectDocument)
         elif action == nwDocAction.SEL_PARA:
-            self._makeSelection(QTextCursor.SelectionType.BlockUnderCursor)
+            self._makeSelection(QtSelectBlock)
         else:
-            logger.debug("Unknown or unsupported document action '%s'", str(action))
+            logger.debug("Unknown or unsupported document action '%s'", action)
             return False
         return True
 
@@ -308,7 +304,6 @@ class GuiDocViewer(QTextBrowser):
     def clearNavHistory(self) -> None:
         """Clear the navigation history."""
         self.docHistory.clear()
-        return
 
     def updateDocMargins(self) -> None:
         """Automatically adjust the margins so the text is centred."""
@@ -337,8 +332,6 @@ class GuiDocViewer(QTextBrowser):
         self.docFooter.setGeometry(tB, fY, tW, fH)
         self.setViewportMargins(tM, max(cM, tH), tM, max(cM, fH))
 
-        return
-
     ##
     #  Setters
     ##
@@ -347,7 +340,6 @@ class GuiDocViewer(QTextBrowser):
         """Set the scrollbar position."""
         if (vBar := self.verticalScrollBar()) and vBar.isVisible():
             vBar.setValue(pos)
-        return
 
     ##
     #  Public Slots
@@ -359,7 +351,6 @@ class GuiDocViewer(QTextBrowser):
         if tHandle == self._docHandle and change == nwChange.UPDATE:
             self.docHeader.setHandle(tHandle)
             self.updateDocMargins()
-        return
 
     @pyqtSlot(str)
     def navigateTo(self, anchor: str) -> None:
@@ -367,7 +358,6 @@ class GuiDocViewer(QTextBrowser):
         if isinstance(anchor, str) and anchor.startswith("#"):
             logger.debug("Moving to anchor '%s'", anchor)
             self.setSource(QUrl(anchor))
-        return
 
     ##
     #  Private Slots
@@ -377,13 +367,11 @@ class GuiDocViewer(QTextBrowser):
     def navBackward(self) -> None:
         """Navigate backwards in the document view history."""
         self.docHistory.backward()
-        return
 
     @pyqtSlot()
     def navForward(self) -> None:
         """Navigate forwards in the document view history."""
         self.docHistory.forward()
-        return
 
     @pyqtSlot("QUrl")
     def _linkClicked(self, url: QUrl) -> None:
@@ -396,7 +384,6 @@ class GuiDocViewer(QTextBrowser):
                 self.navigateTo(link)
             elif link.startswith("http"):
                 QDesktopServices.openUrl(QUrl(url))
-        return
 
     @pyqtSlot("QPoint")
     def _openContextMenu(self, point: QPoint) -> None:
@@ -415,14 +402,10 @@ class GuiDocViewer(QTextBrowser):
         action.triggered.connect(qtLambda(self.docAction, nwDocAction.SEL_ALL))
 
         action = qtAddAction(ctxMenu, self.tr("Select Word"))
-        action.triggered.connect(qtLambda(
-            self._makePosSelection, QTextCursor.SelectionType.WordUnderCursor, point
-        ))
+        action.triggered.connect(qtLambda(self._makePosSelection, QtSelectWord, point))
 
         action = qtAddAction(ctxMenu, self.tr("Select Paragraph"))
-        action.triggered.connect(qtLambda(
-            self._makePosSelection, QTextCursor.SelectionType.BlockUnderCursor, point
-        ))
+        action.triggered.connect(qtLambda(self._makePosSelection, QtSelectBlock, point))
 
         # Open the context menu
         if viewport := self.viewport():
@@ -430,8 +413,6 @@ class GuiDocViewer(QTextBrowser):
 
         ctxMenu.setParent(None)
 
-        return
-
     ##
     #  Events
     ##
@@ -440,7 +421,6 @@ class GuiDocViewer(QTextBrowser):
         """Update document margins when widget is resized."""
         self.updateDocMargins()
         super().resizeEvent(event)
-        return
 
     def mouseReleaseEvent(self, event: QMouseEvent) -> None:
         """Capture mouse click events on the document."""
@@ -450,7 +430,6 @@ class GuiDocViewer(QTextBrowser):
             self.navForward()
         else:
             super().mouseReleaseEvent(event)
-        return
 
     def dragEnterEvent(self, event: QDragEnterEvent) -> None:
         """Overload drag enter event to handle dragged items."""
@@ -458,7 +437,6 @@ class GuiDocViewer(QTextBrowser):
             event.acceptProposedAction()
         else:
             super().dragEnterEvent(event)
-        return
 
     def dragMoveEvent(self, event: QDragMoveEvent) -> None:
         """Overload drag move event to handle dragged items."""
@@ -466,7 +444,6 @@ class GuiDocViewer(QTextBrowser):
             event.acceptProposedAction()
         else:
             super().dragMoveEvent(event)
-        return
 
     def dropEvent(self, event: QDropEvent) -> None:
         """Overload drop event to handle dragged items."""
@@ -476,7 +453,6 @@ class GuiDocViewer(QTextBrowser):
                     self.openDocumentRequest.emit(handles[0], nwDocMode.VIEW, "", True)
         else:
             super().dropEvent(event)
-        return
 
     ##
     #  Internal Functions
@@ -488,7 +464,7 @@ class GuiDocViewer(QTextBrowser):
         cursor.clearSelection()
         cursor.select(selType)
 
-        if selType == QTextCursor.SelectionType.BlockUnderCursor:
+        if selType == QtSelectBlock:
             # This selection mode also selects the preceding paragraph
             # separator, which we want to avoid.
             posS = cursor.selectionStart()
@@ -500,16 +476,18 @@ class GuiDocViewer(QTextBrowser):
 
         self.setTextCursor(cursor)
 
-        return
-
     def _makePosSelection(self, selType: QTextCursor.SelectionType, pos: QPoint) -> None:
         """Handle text selection at a given location."""
         self.setTextCursor(self.cursorForPosition(pos))
         self._makeSelection(selType)
-        return
 
 
 class GuiDocViewHistory:
+    """GUI: Document Viewer History.
+
+    This class holds the navigation history for the viewer panel, which
+    is used for backward/forward navigation.
+    """
 
     def __init__(self, docViewer: GuiDocViewer) -> None:
         self.docViewer = docViewer
@@ -517,7 +495,6 @@ class GuiDocViewHistory:
         self._posHistory = []
         self._currPos = -1
         self._prevPos = -1
-        return
 
     def clear(self) -> None:
         """Clear the view history."""
@@ -526,7 +503,6 @@ class GuiDocViewHistory:
         self._posHistory = []
         self._currPos = -1
         self._prevPos = -1
-        return
 
     def append(self, tHandle: str) -> bool:
         """Append a document handle and its scroll bar position to the
@@ -566,7 +542,6 @@ class GuiDocViewHistory:
             self._currPos = newPos
             self._updateNavButtons()
             self._dumpHistory()
-        return
 
     def backward(self) -> None:
         """Navigate to the previous entry in the view history."""
@@ -580,7 +555,6 @@ class GuiDocViewHistory:
             self._currPos = newPos
             self._updateNavButtons()
             self._dumpHistory()
-        return
 
     ##
     #  Internal Functions
@@ -590,12 +564,10 @@ class GuiDocViewHistory:
         """Update the scrollbar position of the previous entry."""
         if self._prevPos >= 0 and self._prevPos < len(self._posHistory):
             self._posHistory[self._prevPos] = self.docViewer.scrollPosition
-        return
 
     def _updateNavButtons(self) -> None:
         """Update the navigation buttons in the document header."""
         self.docViewer.docHeader.updateNavButtons(0, len(self._navHistory) - 1, self._currPos)
-        return
 
     def _truncateHistory(self, atPos: int) -> None:
         """Truncate the navigation history to the given position. Also
@@ -606,7 +578,6 @@ class GuiDocViewHistory:
         self._posHistory = self._posHistory[nSkip:atPos + 1]
         self._currPos -= nSkip
         self._prevPos -= nSkip
-        return
 
     def _dumpHistory(self) -> None:
         """Debug function to dump history to the logger. Since it is a
@@ -616,11 +587,10 @@ class GuiDocViewHistory:
             for i, (h, p) in enumerate(zip(self._navHistory, self._posHistory, strict=False)):
                 a = ">" if i == self._currPos else " "
                 logger.debug(f"History {i + 1:02d}: {a} {h:13s} [x:{p}]")
-        return
 
 
 class GuiDocViewHeader(QWidget):
-    """The Embedded Document Header
+    """The Embedded Document Header.
 
     Only used by DocViewer, and is at a fixed position in the
     QTextBrowser's viewport.
@@ -711,8 +681,6 @@ class GuiDocViewHeader(QWidget):
 
         logger.debug("Ready: GuiDocViewHeader")
 
-        return
-
     ##
     #  Methods
     ##
@@ -730,7 +698,6 @@ class GuiDocViewHeader(QWidget):
         self.editButton.setVisible(False)
         self.refreshButton.setVisible(False)
         self.closeButton.setVisible(False)
-        return
 
     def setOutline(self, data: dict[str, tuple[str, int]]) -> None:
         """Set the document outline dataset."""
@@ -750,22 +717,22 @@ class GuiDocViewHeader(QWidget):
                     lambda _, title=title: self.docViewer.navigateTo(f"#{tHandle}:{title}")
                 )
             self._docOutline = data
-        return
 
     def updateFont(self) -> None:
         """Update the font settings."""
         self.setFont(SHARED.theme.guiFont)
         self.itemTitle.setFont(SHARED.theme.guiFontSmall)
-        return
 
     def updateTheme(self) -> None:
         """Update theme elements."""
-        self.outlineButton.setThemeIcon("list", "blue")
-        self.backButton.setThemeIcon("chevron_left", "blue")
-        self.forwardButton.setThemeIcon("chevron_right", "blue")
-        self.editButton.setThemeIcon("edit", "green")
-        self.refreshButton.setThemeIcon("refresh", "green")
-        self.closeButton.setThemeIcon("close", "red")
+        logger.debug("Theme Update: GuiDocViewHeader")
+
+        self.outlineButton.setThemeIcon("list", "action")
+        self.backButton.setThemeIcon("chevron_left", "action")
+        self.forwardButton.setThemeIcon("chevron_right", "action")
+        self.editButton.setThemeIcon("edit", "change")
+        self.refreshButton.setThemeIcon("refresh", "change")
+        self.closeButton.setThemeIcon("close", "reject")
 
         buttonStyle = SHARED.theme.getStyleSheet(STYLES_MIN_TOOLBUTTON)
         self.outlineButton.setStyleSheet(buttonStyle)
@@ -777,8 +744,6 @@ class GuiDocViewHeader(QWidget):
 
         self.matchColors()
 
-        return
-
     def matchColors(self) -> None:
         """Update the colours of the widget to match those of the syntax
         theme rather than the main GUI.
@@ -792,15 +757,13 @@ class GuiDocViewHeader(QWidget):
         self.itemTitle.setTextColors(
             color=palette.windowText().color(), faded=SHARED.theme.fadedText
         )
-        return
 
     def changeFocusState(self, state: bool) -> None:
         """Toggle focus state."""
-        self.itemTitle.setColorState(state)
-        return
+        self.itemTitle.setColorState(nwState.NORMAL if state else nwState.INACTIVE)
 
     def setHandle(self, tHandle: str) -> None:
-        """Sets the document title from the handle, or alternatively,
+        """Set the document title from the handle, or alternatively,
         set the whole document path.
         """
         self._docHandle = tHandle
@@ -819,13 +782,10 @@ class GuiDocViewHeader(QWidget):
         self.refreshButton.setVisible(True)
         self.closeButton.setVisible(True)
 
-        return
-
     def updateNavButtons(self, firstIdx: int, lastIdx: int, currIdx: int) -> None:
         """Enable and disable nav buttons based on index in history."""
         self.backButton.setEnabled(currIdx > firstIdx)
         self.forwardButton.setEnabled(currIdx < lastIdx)
-        return
 
     ##
     #  Private Slots
@@ -836,20 +796,17 @@ class GuiDocViewHeader(QWidget):
         """Trigger the close editor/viewer on the main window."""
         self.clearHeader()
         self.docViewer.closeDocumentRequest.emit()
-        return
 
     @pyqtSlot()
     def _refreshDocument(self) -> None:
         """Reload the content of the document."""
         self.docViewer.reloadDocumentRequest.emit()
-        return
 
     @pyqtSlot()
     def _editDocument(self) -> None:
         """Open the document in the editor."""
         if tHandle := self._docHandle:
             self.docViewer.openDocumentRequest.emit(tHandle, nwDocMode.EDIT, "", True)
-        return
 
     ##
     #  Events
@@ -861,11 +818,10 @@ class GuiDocViewHeader(QWidget):
         """
         if event.button() == QtMouseLeft:
             self.docViewer.requestProjectItemSelected.emit(self._docHandle, True)
-        return
 
 
 class GuiDocViewFooter(QWidget):
-    """The Embedded Document Footer
+    """The Embedded Document Footer.
 
     Only used by DocViewer, and is at a fixed position in the
     QTextBrowser's viewport.
@@ -913,12 +869,23 @@ class GuiDocViewFooter(QWidget):
         self.showSynopsis.toggled.connect(self._doToggleSynopsis)
         self.showSynopsis.setToolTip(self.tr("Show Synopsis Comments"))
 
+        # Show Notes
+        self.showNotes = QToolButton(self)
+        self.showNotes.setText(self.tr("Notes"))
+        self.showNotes.setCheckable(True)
+        self.showNotes.setChecked(CONFIG.viewNotes)
+        self.showNotes.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonTextBesideIcon)
+        self.showNotes.setIconSize(iSz)
+        self.showNotes.toggled.connect(self._doToggleNotes)
+        self.showNotes.setToolTip(self.tr("Show Notes"))
+
         # Assemble Layout
         self.outerBox = QHBoxLayout()
         self.outerBox.addWidget(self.showHide, 0)
         self.outerBox.addStretch(1)
         self.outerBox.addWidget(self.showComments, 0)
         self.outerBox.addWidget(self.showSynopsis, 0)
+        self.outerBox.addWidget(self.showNotes, 0)
         self.outerBox.setSpacing(4)
         self.setLayout(self.outerBox)
 
@@ -933,8 +900,6 @@ class GuiDocViewFooter(QWidget):
 
         logger.debug("Ready: GuiDocViewFooter")
 
-        return
-
     ##
     #  Methods
     ##
@@ -944,27 +909,28 @@ class GuiDocViewFooter(QWidget):
         self.setFont(SHARED.theme.guiFont)
         self.showComments.setFont(SHARED.theme.guiFontSmall)
         self.showSynopsis.setFont(SHARED.theme.guiFontSmall)
-        return
+        self.showNotes.setFont(SHARED.theme.guiFontSmall)
 
     def updateTheme(self) -> None:
         """Update theme elements."""
-        # Icons
-        fPx = int(0.9*SHARED.theme.fontPixelSize)
-        bulletIcon = SHARED.theme.getToggleIcon("bullet", (fPx, fPx), "blue")
+        logger.debug("Theme Update: GuiDocViewFooter")
 
-        self.showHide.setThemeIcon("panel")
+        fPx = int(0.9*SHARED.theme.fontPixelSize)
+        bulletIcon = SHARED.theme.getToggleIcon("bullet", (fPx, fPx), "action")
+
+        self.showHide.setThemeIcon("panel", "default")
         self.showComments.setIcon(bulletIcon)
         self.showSynopsis.setIcon(bulletIcon)
+        self.showNotes.setIcon(bulletIcon)
 
         buttonStyle = SHARED.theme.getStyleSheet(STYLES_MIN_TOOLBUTTON)
         self.showHide.setStyleSheet(buttonStyle)
         self.showComments.setStyleSheet(buttonStyle)
         self.showSynopsis.setStyleSheet(buttonStyle)
+        self.showNotes.setStyleSheet(buttonStyle)
 
         self.matchColors()
 
-        return
-
     def matchColors(self) -> None:
         """Update the colours of the widget to match those of the syntax
         theme rather than the main GUI.
@@ -975,7 +941,6 @@ class GuiDocViewFooter(QWidget):
         palette.setColor(QPalette.ColorRole.WindowText, syntax.text)
         palette.setColor(QPalette.ColorRole.Text, syntax.text)
         self.setPalette(palette)
-        return
 
     ##
     #  Private Slots
@@ -986,11 +951,15 @@ class GuiDocViewFooter(QWidget):
         """Toggle the view comment button and reload the document."""
         CONFIG.viewComments = state
         self.docViewer.reloadText()
-        return
 
     @pyqtSlot(bool)
     def _doToggleSynopsis(self, state: bool) -> None:
         """Toggle the view synopsis button and reload the document."""
         CONFIG.viewSynopsis = state
         self.docViewer.reloadText()
-        return
+
+    @pyqtSlot(bool)
+    def _doToggleNotes(self, state: bool) -> None:
+        """Toggle the view notes button and reload the document."""
+        CONFIG.viewNotes = state
+        self.docViewer.reloadText()
