@@ -25,7 +25,7 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program. If not, see <https://www.gnu.org/licenses/>.
-"""
+"""  # noqa
 from __future__ import annotations
 
 import logging
@@ -61,7 +61,9 @@ logger = logging.getLogger(__name__)
 
 
 class GuiProjectView(QWidget):
-    """This is a wrapper class holding all the elements of the project
+    """GUI: Project View.
+
+    This is a wrapper class holding all the elements of the project
     tree. The core object is the project tree itself. Most methods
     available are mapped through to the project tree class.
     """
@@ -130,28 +132,24 @@ class GuiProjectView(QWidget):
         # Function Mappings
         self.getSelectedHandle = self.projTree.getSelectedHandle
 
-        return
-
     ##
     #  Methods
     ##
 
     def updateTheme(self) -> None:
         """Update theme elements."""
+        logger.debug("Theme Update: GuiProjectView")
         self.projBar.updateTheme()
-        return
 
     def initSettings(self) -> None:
         """Initialise GUI elements that depend on specific settings."""
         self.projTree.initSettings()
-        return
 
     def closeProjectTasks(self) -> None:
         """Clear project-related GUI content."""
         self.projBar.clearContent()
         self.projBar.setEnabled(False)
         self.projTree.clearTree()
-        return
 
     def openProjectTasks(self) -> None:
         """Run open project tasks."""
@@ -159,26 +157,23 @@ class GuiProjectView(QWidget):
         self.projBar.buildTemplatesMenu()
         self.projBar.buildQuickLinksMenu()
         self.projBar.setEnabled(True)
-        return
 
     def setTreeFocus(self) -> None:
         """Forward the set focus call to the tree widget."""
         self.projTree.setFocus()
-        return
 
     def treeHasFocus(self) -> bool:
         """Check if the project tree has focus."""
         return self.projTree.hasFocus()
 
     def connectMenuActions(self, rename: QAction, delete: QAction, trash: QAction) -> None:
-        """Main menu actions passed to the project tree."""
+        """Connect main menu actions passed to the project tree."""
         self.projTree.addAction(rename)
         self.projTree.addAction(delete)
         self.projTree.addAction(trash)
         rename.triggered.connect(self.renameTreeItem)
         delete.triggered.connect(self.projTree.processDeleteRequest)
         trash.triggered.connect(self.projTree.emptyTrash)
-        return
 
     ##
     #  Public Slots
@@ -197,41 +192,36 @@ class GuiProjectView(QWidget):
             if dlgOk:
                 nwItem.setName(newLabel)
                 nwItem.notifyToRefresh()
-        return
 
     @pyqtSlot(str, bool)
     def setSelectedHandle(self, tHandle: str, doScroll: bool = False) -> None:
         """Select an item and optionally scroll it into view."""
         self.projTree.setSelectedHandle(tHandle, doScroll=doScroll)
-        return
 
     @pyqtSlot(str)
     def setActiveHandle(self, tHandle: str | None) -> None:
         """Highlight the active handle."""
         self.projTree.setActiveHandle(tHandle)
-        return
 
     @pyqtSlot(str, Enum)
     def onProjectItemChanged(self, tHandle: str, change: nwChange) -> None:
         """Refresh other content when project item changed."""
         self.projBar.processTemplateDocuments(tHandle)
-        return
 
     @pyqtSlot(str)
     def createFileFromTemplate(self, tHandle: str) -> None:
         """Create a new document from a template."""
         logger.debug("Template selected: '%s'", tHandle)
         self.projTree.newTreeItem(nwItemType.FILE, copyDoc=tHandle)
-        return
 
     @pyqtSlot(str, Enum)
     def updateRootItem(self, tHandle: str, change: nwChange) -> None:
         """Process root item changes."""
         self.projBar.buildQuickLinksMenu()
-        return
 
 
 class GuiProjectToolBar(QWidget):
+    """GUI> Project View ToolBar."""
 
     newDocumentFromTemplate = pyqtSignal(str)
 
@@ -351,14 +341,14 @@ class GuiProjectToolBar(QWidget):
 
         logger.debug("Ready: GuiProjectToolBar")
 
-        return
-
     ##
     #  Methods
     ##
 
     def updateTheme(self) -> None:
         """Update theme elements."""
+        logger.debug("Theme Update: GuiProjectToolBar")
+
         buttonStyle = SHARED.theme.getStyleSheet(STYLES_MIN_TOOLBUTTON)
         self.tbQuick.setStyleSheet(buttonStyle)
         self.tbMoveU.setStyleSheet(buttonStyle)
@@ -366,11 +356,11 @@ class GuiProjectToolBar(QWidget):
         self.tbAdd.setStyleSheet(buttonStyle)
         self.tbMore.setStyleSheet(buttonStyle)
 
-        self.tbQuick.setThemeIcon("bookmarks", "blue")
-        self.tbMoveU.setThemeIcon("chevron_up", "blue")
-        self.tbMoveD.setThemeIcon("chevron_down", "blue")
-        self.tbAdd.setThemeIcon("add", "green")
-        self.tbMore.setThemeIcon("more_vertical")
+        self.tbQuick.setThemeIcon("bookmarks", "action")
+        self.tbMoveU.setThemeIcon("chevron_up", "action")
+        self.tbMoveD.setThemeIcon("chevron_down", "action")
+        self.tbAdd.setThemeIcon("add", "add")
+        self.tbMore.setThemeIcon("more_vertical", "default")
 
         self.aAddScene.setIcon(SHARED.theme.getIcon("prj_scene", "scene"))
         self.aAddChap.setIcon(SHARED.theme.getIcon("prj_chapter", "chapter"))
@@ -383,13 +373,10 @@ class GuiProjectToolBar(QWidget):
         self.buildQuickLinksMenu()
         self._buildRootMenu()
 
-        return
-
     def clearContent(self) -> None:
         """Clear dynamic content on the tool bar."""
         self.mQuick.clear()
         self.mTemplates.clearMenu()
-        return
 
     def buildQuickLinksMenu(self) -> None:
         """Build the quick link menu."""
@@ -402,14 +389,12 @@ class GuiProjectToolBar(QWidget):
             action.triggered.connect(
                 qtLambda(self.projView.setSelectedHandle, tHandle, doScroll=True)
             )
-        return
 
     def buildTemplatesMenu(self) -> None:
         """Build the templates menu."""
         for tHandle, _ in SHARED.project.tree.iterRoots(nwItemClass.TEMPLATE):
             for dHandle in SHARED.project.tree.subTree(tHandle):
                 self.processTemplateDocuments(dHandle)
-        return
 
     def processTemplateDocuments(self, tHandle: str) -> None:
         """Process change in tree items to update menu content."""
@@ -418,7 +403,6 @@ class GuiProjectToolBar(QWidget):
                 self.mTemplates.addUpdate(tHandle, item.itemName, item.getMainIcon())
             elif tHandle in self.mTemplates:
                 self.mTemplates.remove(tHandle)
-        return
 
     ##
     #  Public Slots
@@ -436,7 +420,6 @@ class GuiProjectToolBar(QWidget):
         self.aAddChap.setVisible(allowDoc)
         self.aAddPart.setVisible(allowDoc)
         self.aAddEmpty.setVisible(allowDoc)
-        return
 
     ##
     #  Internal Functions
@@ -451,7 +434,6 @@ class GuiProjectToolBar(QWidget):
                 qtLambda(self.projTree.newTreeItem, nwItemType.ROOT, itemClass)
             )
             self.mAddRoot.addAction(aNew)
-            return
 
         self.mAddRoot.clear()
         addClass(nwItemClass.NOVEL)
@@ -467,10 +449,9 @@ class GuiProjectToolBar(QWidget):
         addClass(nwItemClass.ARCHIVE)
         addClass(nwItemClass.TEMPLATE)
 
-        return
-
 
 class GuiProjectTree(QTreeView):
+    """GUI: Project View Tree."""
 
     def __init__(self, projView: GuiProjectView) -> None:
         super().__init__(parent=projView)
@@ -520,8 +501,6 @@ class GuiProjectTree(QTreeView):
 
         logger.debug("Ready: GuiProjectTree")
 
-        return
-
     def initSettings(self) -> None:
         """Set or update tree widget settings."""
         if CONFIG.hideVScroll:
@@ -532,7 +511,6 @@ class GuiProjectTree(QTreeView):
             self.setHorizontalScrollBarPolicy(QtScrollAlwaysOff)
         else:
             self.setHorizontalScrollBarPolicy(QtScrollAsNeeded)
-        return
 
     ##
     #  External Methods
@@ -541,7 +519,6 @@ class GuiProjectTree(QTreeView):
     def setActiveHandle(self, tHandle: str | None) -> None:
         """Set the handle to be highlighted."""
         self._actHandle = tHandle
-        return
 
     def getSelectedHandle(self) -> str | None:
         """Get the currently selected handle."""
@@ -556,7 +533,6 @@ class GuiProjectTree(QTreeView):
     def clearTree(self) -> None:
         """Clear the tree view."""
         self.setModel(None)
-        return
 
     def loadModel(self) -> None:
         """Load and prepare a new project model."""
@@ -583,8 +559,6 @@ class GuiProjectTree(QTreeView):
 
         self.restoreExpandedState()
 
-        return
-
     def restoreExpandedState(self) -> None:
         """Expand all nodes that were previously expanded."""
         if model := self._getModel():
@@ -592,7 +566,6 @@ class GuiProjectTree(QTreeView):
             for index in model.allExpanded():
                 self.setExpanded(index, True)
             self.blockSignals(False)
-        return
 
     def setSelectedHandle(self, tHandle: str | None, doScroll: bool = False) -> None:
         """Set a specific handle as the selected item."""
@@ -601,7 +574,6 @@ class GuiProjectTree(QTreeView):
             if doScroll:
                 self.scrollTo(index, QAbstractItemView.ScrollHint.PositionAtCenter)
             self.projView.selectedItemChanged.emit(tHandle)
-        return
 
     def newTreeItem(
         self, itemType: nwItemType, itemClass: nwItemClass | None = None,
@@ -667,7 +639,7 @@ class GuiProjectTree(QTreeView):
                     if itemType == nwItemType.FILE:
                         if tHandle := SHARED.project.newFile(newLabel, sHandle, sPos):
                             if copyDoc:
-                                SHARED.project.copyFileContent(tHandle, copyDoc)
+                                SHARED.project.copyFileContent(tHandle, copyDoc, newLabel)
                             elif hLevel > 0:
                                 SHARED.project.writeNewFile(tHandle, hLevel, not nNote)
                             SHARED.project.index.reIndexHandle(tHandle)
@@ -718,9 +690,15 @@ class GuiProjectTree(QTreeView):
         else:
             return False
 
+        SHARED.initMainProgress(len(items))
+        self.setEnabled(False)
         for sHandle in items:
+            SHARED.incMainProgress()
             docMerger.appendText(sHandle, True, mLabel)
 
+        self.setEnabled(True)
+        SHARED.clearMainProgress()
+
         if not docMerger.writeTargetDoc():
             SHARED.error(
                 self.tr("Could not write document content."),
@@ -764,7 +742,10 @@ class GuiProjectTree(QTreeView):
             docSplit.setParentItem(tItem.itemParent)
 
         docSplit.splitDocument(headerList, text)
+        SHARED.initMainProgress(len(docSplit))
+        self.setEnabled(False)
         for writeOk in docSplit.writeDocuments(docHierarchy):
+            SHARED.incMainProgress()
             if not writeOk:
                 SHARED.error(
                     self.tr("Could not write document content."),
@@ -774,6 +755,9 @@ class GuiProjectTree(QTreeView):
         if data.get("moveToTrash", False):
             self.processDeleteRequest([tHandle], False)
 
+        self.setEnabled(True)
+        SHARED.clearMainProgress()
+
         return True
 
     def duplicateFromHandle(self, tHandle: str) -> None:
@@ -786,12 +770,13 @@ class GuiProjectTree(QTreeView):
             else:
                 question = self.tr("Do you want to duplicate this item and all child items?")
             if SHARED.question(question):
+                self.setEnabled(False)
                 docDup = DocDuplicator(SHARED.project)
                 dHandles = docDup.duplicate(itemTree)
                 if len(dHandles) != len(itemTree):
                     SHARED.warn(self.tr("Could not duplicate all items."))
+                self.setEnabled(True)
         self.restoreExpandedState()
-        return
 
     ##
     #  Events and Overloads
@@ -811,14 +796,12 @@ class GuiProjectTree(QTreeView):
                 self.projView.openDocumentRequest.emit(
                     node.item.itemHandle, nwDocMode.VIEW, "", False
                 )
-        return
 
     def drawRow(self, painter: QPainter, opt: QStyleOptionViewItem, index: QModelIndex) -> None:
         """Draw a box on the active row."""
         if (node := self._getNode(index)) and node.item.itemHandle == self._actHandle:
             painter.fillRect(opt.rect, self.palette().alternateBase())
         super().drawRow(painter, opt, index)
-        return
 
     ##
     #  Public Slots
@@ -829,14 +812,12 @@ class GuiProjectTree(QTreeView):
         """Move an item up in the tree."""
         if model := self._getModel():
             model.internalMove(self.currentIndex(), -1)
-        return
 
     @pyqtSlot()
     def moveItemDown(self) -> None:
         """Move an item down in the tree."""
         if model := self._getModel():
             model.internalMove(self.currentIndex(), 1)
-        return
 
     @pyqtSlot()
     def goToSiblingUp(self) -> None:
@@ -844,7 +825,6 @@ class GuiProjectTree(QTreeView):
         if (node := self._getNode(self.currentIndex())) and (parent := node.parent()):
             if (move := parent.child(node.row() - 1)) and (model := self._getModel()):
                 self.setCurrentIndex(model.indexFromNode(move))
-        return
 
     @pyqtSlot()
     def goToSiblingDown(self) -> None:
@@ -852,7 +832,6 @@ class GuiProjectTree(QTreeView):
         if (node := self._getNode(self.currentIndex())) and (parent := node.parent()):
             if (move := parent.child(node.row() + 1)) and (model := self._getModel()):
                 self.setCurrentIndex(model.indexFromNode(move))
-        return
 
     @pyqtSlot()
     def goToParent(self) -> None:
@@ -863,7 +842,6 @@ class GuiProjectTree(QTreeView):
             and (parent := node.parent())
         ):
             self.setCurrentIndex(model.indexFromNode(parent))
-        return
 
     @pyqtSlot()
     def goToFirstChild(self) -> None:
@@ -874,13 +852,11 @@ class GuiProjectTree(QTreeView):
             and (child := node.child(0))
         ):
             self.setCurrentIndex(model.indexFromNode(child))
-        return
 
     @pyqtSlot(QModelIndex)
     def expandFromIndex(self, index: QModelIndex) -> None:
         """Expand all nodes from index."""
         self.expandRecursively(index)
-        return
 
     @pyqtSlot(QModelIndex)
     def collapseFromIndex(self, index: QModelIndex) -> None:
@@ -888,7 +864,6 @@ class GuiProjectTree(QTreeView):
         if (model := self._getModel()) and (node := model.node(index)):
             for child in node.allChildren():
                 self.setExpanded(model.indexFromNode(child), False)
-        return
 
     @pyqtSlot()
     def processDeleteRequest(
@@ -912,17 +887,23 @@ class GuiProjectTree(QTreeView):
                 if not SHARED.question(self.tr("Permanently delete selected item(s)?")):
                     logger.info("Action cancelled by user")
                     return
+
+                self.setEnabled(False)
                 for index in indices:
                     if node := model.node(index):
                         for child in reversed(node.allChildren()):
                             SHARED.project.removeItem(child.item.itemHandle)
                         SHARED.project.removeItem(node.item.itemHandle)
+                self.setEnabled(True)
 
             elif trashNode := SHARED.project.tree.trash:
                 if askFirst and not SHARED.question(self.tr("Move selected item(s) to Trash?")):
                     logger.info("Action cancelled by user")
                     return
+
+                self.setEnabled(False)
                 model.multiMove(indices, model.indexFromNode(trashNode))
+                self.setEnabled(True)
 
         return
 
@@ -948,9 +929,7 @@ class GuiProjectTree(QTreeView):
     @pyqtSlot()
     @pyqtSlot("QPoint")
     def openContextMenu(self, point: QPoint | None = None) -> None:
-        """The user right clicked an element in the project tree, so we
-        open a context menu in-place.
-        """
+        """Open a context menu in-place where the user clicked."""
         if model := self._getModel():
             if point is None:
                 point = self.visualRect(self.currentIndex()).center()
@@ -967,7 +946,6 @@ class GuiProjectTree(QTreeView):
                     if viewport := self.viewport():
                         ctxMenu.exec(viewport.mapToGlobal(point))
                     ctxMenu.setParent(None)
-        return
 
     ##
     #  Private Slots
@@ -975,10 +953,9 @@ class GuiProjectTree(QTreeView):
 
     @pyqtSlot(QModelIndex, QModelIndex)
     def _onSelectionChange(self, current: QModelIndex, previous: QModelIndex) -> None:
-        """The user changed which item is selected."""
+        """Process user changing which item is selected."""
         if node := self._getNode(current):
             self.projView.selectedItemChanged.emit(node.item.itemHandle)
-        return
 
     @pyqtSlot(QModelIndex)
     def _onDoubleClick(self, index: QModelIndex) -> None:
@@ -992,21 +969,18 @@ class GuiProjectTree(QTreeView):
                 )
             else:
                 self.setExpanded(index, not self.isExpanded(index))
-        return
 
     @pyqtSlot(QModelIndex)
     def _onNodeCollapsed(self, index: QModelIndex) -> None:
         """Capture a node collapse, and pass it to the model."""
         if node := self._getNode(index):
             node.setExpanded(False)
-        return
 
     @pyqtSlot(QModelIndex)
     def _onNodeExpanded(self, index: QModelIndex) -> None:
         """Capture a node expand, and pass it to the model."""
         if node := self._getNode(index):
             node.setExpanded(True)
-        return
 
     ##
     #  Internal Functions
@@ -1018,7 +992,6 @@ class GuiProjectTree(QTreeView):
         if model := self.selectionModel():
             # Selection model can be None (#2173)
             model.clearCurrentIndex()
-        return
 
     def _selectedRows(self) -> list[QModelIndex]:
         """Return all column 0 indexes."""
@@ -1046,7 +1019,6 @@ class _UpdatableMenu(QMenu):
         self._map: dict[str, QAction] = {}
         self.setTitle(self.tr("From Template"))
         self.triggered.connect(self._actionTriggered)
-        return
 
     def __contains__(self, tHandle: str) -> bool:
         """Look up a handle in the menu."""
@@ -1068,7 +1040,6 @@ class _UpdatableMenu(QMenu):
             self.addAction(action)
             self._map[tHandle] = action
         self.setActionsVisible(True)
-        return
 
     def remove(self, tHandle: str) -> None:
         """Remove a template item."""
@@ -1076,19 +1047,16 @@ class _UpdatableMenu(QMenu):
             self.removeAction(action)
         if not self._map:
             self.setActionsVisible(False)
-        return
 
     def clearMenu(self) -> None:
         """Clear all menu content."""
         self._map.clear()
         self.clear()
-        return
 
     def setActionsVisible(self, value: bool) -> None:
         """Set the visibility of root action."""
         if action := self.menuAction():
             action.setVisible(value)
-        return
 
     ##
     #  Private Slots
@@ -1098,7 +1066,6 @@ class _UpdatableMenu(QMenu):
     def _actionTriggered(self, action: QAction) -> None:
         """Translate the menu trigger into an item trigger."""
         self.menuItemTriggered.emit(str(action.data()))
-        return
 
 
 class _TreeContextMenu(QMenu):
@@ -1119,11 +1086,9 @@ class _TreeContextMenu(QMenu):
         self._indices = indices
         self._children = node.childCount() > 0
         logger.debug("Ready: _TreeContextMenu")
-        return
 
     def __del__(self) -> None:  # pragma: no cover
         logger.debug("Delete: _TreeContextMenu")
-        return
 
     ##
     #  Methods
@@ -1135,7 +1100,6 @@ class _TreeContextMenu(QMenu):
         action.triggered.connect(self._tree.emptyTrash)
         if self._children:
             self._expandCollapse()
-        return
 
     def buildSingleSelectMenu(self) -> None:
         """Build the single-select menu."""
@@ -1171,15 +1135,12 @@ class _TreeContextMenu(QMenu):
         action.triggered.connect(qtLambda(self._tree.duplicateFromHandle, self._handle))
         self._deleteOrTrash()
 
-        return
-
     def buildMultiSelectMenu(self) -> None:
         """Build the multi-select menu."""
         self._itemActive()
         self._itemStatusImport(True)
         self.addSeparator()
         self._deleteOrTrash()
-        return
 
     ##
     #  Menu Builders
@@ -1197,7 +1158,6 @@ class _TreeContextMenu(QMenu):
             self._view.openDocumentRequest.emit,
             self._handle, nwDocMode.VIEW, "", False
         ))
-        return
 
     def _itemCreation(self) -> None:
         """Add create item actions."""
@@ -1208,7 +1168,6 @@ class _TreeContextMenu(QMenu):
         menu.addAction(self._view.projBar.aAddEmpty)
         menu.addAction(self._view.projBar.aAddNote)
         menu.addAction(self._view.projBar.aAddFolder)
-        return
 
     def _itemHeader(self) -> None:
         """Check if there is a header that can be used for rename."""
@@ -1218,22 +1177,20 @@ class _TreeContextMenu(QMenu):
             action.triggered.connect(
                 qtLambda(self._view.renameTreeItem, self._handle, hItem.title)
             )
-        return
 
     def _itemActive(self) -> None:
         """Add Active/Inactive actions."""
         if len(self._indices) > 1:
             mSub = qtAddMenu(self, self.tr("Set Active to ..."))
             aOne = qtAddAction(mSub, self._tree.trActive)
-            aOne.setIcon(SHARED.theme.getIcon("checked", "green"))
+            aOne.setIcon(SHARED.theme.getIcon("checked", "accept"))
             aOne.triggered.connect(qtLambda(self._iterItemActive, True))
             aTwo = qtAddAction(mSub, self._tree.trInactive)
-            aTwo.setIcon(SHARED.theme.getIcon("unchecked", "red"))
+            aTwo.setIcon(SHARED.theme.getIcon("unchecked", "reject"))
             aTwo.triggered.connect(qtLambda(self._iterItemActive, False))
         else:
             action = qtAddAction(self, self.tr("Toggle Active"))
             action.triggered.connect(self._toggleItemActive)
-        return
 
     def _itemStatusImport(self, multi: bool) -> None:
         """Add actions for changing status or importance."""
@@ -1275,7 +1232,6 @@ class _TreeContextMenu(QMenu):
                 self._view.projectSettingsRequest.emit,
                 GuiProjectSettings.PAGE_IMPORT
             ))
-        return
 
     def _itemTransform(self, isFile: bool, isFolder: bool) -> None:
         """Add actions for the Transform menu."""
@@ -1318,15 +1274,12 @@ class _TreeContextMenu(QMenu):
             action = qtAddAction(menu, self.tr("Split Document by Headings"))
             action.triggered.connect(qtLambda(self._tree.splitDocument, self._handle))
 
-        return
-
     def _expandCollapse(self) -> None:
         """Add actions for expand and collapse."""
         action = qtAddAction(self, self.tr("Expand All"))
         action.triggered.connect(qtLambda(self._tree.expandFromIndex, self._indices[0]))
         action = qtAddAction(self, self.tr("Collapse All"))
         action.triggered.connect(qtLambda(self._tree.collapseFromIndex, self._indices[0]))
-        return
 
     def _deleteOrTrash(self) -> None:
         """Add move to Trash action."""
@@ -1339,7 +1292,6 @@ class _TreeContextMenu(QMenu):
             text = self.tr("Move to Trash")
         action = qtAddAction(self, text)
         action.triggered.connect(self._tree.processDeleteRequest)
-        return
 
     ##
     #  Private Slots
@@ -1351,7 +1303,6 @@ class _TreeContextMenu(QMenu):
         if self._item.isFileType():
             self._item.setActive(not self._item.isActive)
             self._item.notifyToRefresh()
-        return
 
     ##
     #  Internal Functions
@@ -1365,13 +1316,11 @@ class _TreeContextMenu(QMenu):
                 node.item.setActive(state)
                 refresh.append(node.item.itemHandle)
         SHARED.project.tree.refreshItems(refresh)
-        return
 
     def _changeItemStatus(self, key: str) -> None:
         """Set a new status value of an item."""
         self._item.setStatus(key)
         self._item.notifyToRefresh()
-        return
 
     def _iterSetItemStatus(self, key: str) -> None:
         """Change the status value for multiple items."""
@@ -1381,13 +1330,11 @@ class _TreeContextMenu(QMenu):
                 node.item.setStatus(key)
                 refresh.append(node.item.itemHandle)
         SHARED.project.tree.refreshItems(refresh)
-        return
 
     def _changeItemImport(self, key: str) -> None:
         """Set a new importance value of an item."""
         self._item.setImport(key)
         self._item.notifyToRefresh()
-        return
 
     def _iterSetItemImport(self, key: str) -> None:
         """Change the status value for multiple items."""
@@ -1397,7 +1344,6 @@ class _TreeContextMenu(QMenu):
                 node.item.setImport(key)
                 refresh.append(node.item.itemHandle)
         SHARED.project.tree.refreshItems(refresh)
-        return
 
     def _changeItemLayout(self, itemLayout: nwItemLayout) -> None:
         """Set a new item layout value of an item."""
@@ -1408,7 +1354,6 @@ class _TreeContextMenu(QMenu):
         elif itemLayout == nwItemLayout.NOTE:
             self._item.setLayout(nwItemLayout.NOTE)
             self._item.notifyToRefresh()
-        return
 
     def _convertFolderToFile(self, itemLayout: nwItemLayout) -> None:
         """Convert a folder to a note or document."""
@@ -1428,4 +1373,3 @@ class _TreeContextMenu(QMenu):
                 self._item.notifyToRefresh()
             else:
                 logger.info("Folder conversion cancelled")
-        return
