@@ -20,7 +20,7 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program. If not, see <https://www.gnu.org/licenses/>.
-"""
+"""  # noqa
 from __future__ import annotations
 
 import logging
@@ -37,9 +37,13 @@ from PyQt6.QtWidgets import (
 )
 
 from novelwriter import CONFIG, SHARED
-from novelwriter.common import describeFont, fontMatcher, qtAddAction, qtLambda
+from novelwriter.common import (
+    describeFont, fontMatcher, languageName, processLangCode, qtAddAction,
+    qtLambda
+)
 from novelwriter.constants import nwHeadFmt, nwKeyWords, nwLabels, nwUnicode, trConst
 from novelwriter.core.buildsettings import BuildSettings, FilterMode
+from novelwriter.enum import nwStandardButton
 from novelwriter.extensions.configlayout import (
     NColorLabel, NFixedPage, NScrollableForm, NScrollablePage
 )
@@ -50,9 +54,8 @@ from novelwriter.extensions.pagedsidebar import NPagedSideBar
 from novelwriter.extensions.switch import NSwitch
 from novelwriter.extensions.switchbox import NSwitchBox
 from novelwriter.types import (
-    QtAlignCenter, QtAlignLeft, QtDialogApply, QtDialogClose, QtDialogSave,
-    QtHeaderFixed, QtHeaderStretch, QtRoleAccept, QtRoleApply, QtRoleReject,
-    QtUserRole
+    QtAlignCenter, QtAlignLeft, QtAlignRightMiddle, QtHeaderFixed,
+    QtHeaderStretch, QtRoleAccept, QtRoleApply, QtRoleDestruct, QtUserRole
 )
 
 if TYPE_CHECKING:
@@ -62,7 +65,7 @@ logger = logging.getLogger(__name__)
 
 
 class GuiBuildSettings(NToolDialog):
-    """GUI Tools: Manuscript Build Settings Dialog
+    """GUI Tools: Manuscript Build Settings Dialog.
 
     The main tool for configuring manuscript builds. It's a GUI tool for
     editing JSON build definitions, wrapped as a BuildSettings object.
@@ -72,7 +75,7 @@ class GuiBuildSettings(NToolDialog):
     OPT_HEADINGS   = 2
     OPT_FORMATTING = 10
 
-    newSettingsReady = pyqtSignal(BuildSettings)
+    newSettingsReady = pyqtSignal(BuildSettings, bool)
 
     def __init__(self, parent: GuiMain, build: BuildSettings) -> None:
         super().__init__(parent=parent)
@@ -86,6 +89,7 @@ class GuiBuildSettings(NToolDialog):
         self.setWindowTitle(self.tr("Manuscript Build Settings"))
         self.setMinimumSize(700, 400)
 
+        iPx = SHARED.theme.baseIconHeight
         options = SHARED.project.options
         self.resize(
             options.getInt("GuiBuildSettings", "winWidth", 750),
@@ -124,9 +128,23 @@ class GuiBuildSettings(NToolDialog):
         self.toolStack.addWidget(self.optTabHeadings)
         self.toolStack.addWidget(self.optTabFormatting)
 
+        # Preview
+        self.swtAutoPreview = NSwitch(self, height=iPx)
+        self.swtAutoPreview.setChecked(options.getBool("GuiBuildSettings", "autoPreview", True))
+
+        self.lblAutoPreview = QLabel(self.tr("Auto-Update Preview"), self)
+        self.lblAutoPreview.setBuddy(self.swtAutoPreview)
+
         # Buttons
-        self.buttonBox = QDialogButtonBox(QtDialogApply | QtDialogSave | QtDialogClose, self)
-        self.buttonBox.clicked.connect(self._dialogButtonClicked)
+        self.btnApply = SHARED.theme.getStandardButton(nwStandardButton.APPLY, self)
+        self.btnSave = SHARED.theme.getStandardButton(nwStandardButton.SAVE, self)
+        self.btnClose = SHARED.theme.getStandardButton(nwStandardButton.CLOSE, self)
+
+        self.btnBox = QDialogButtonBox(self)
+        self.btnBox.addButton(self.btnApply, QtRoleApply)
+        self.btnBox.addButton(self.btnSave, QtRoleAccept)
+        self.btnBox.addButton(self.btnClose, QtRoleDestruct)
+        self.btnBox.clicked.connect(self._dialogButtonClicked)
 
         # Assemble
         self.topBox = QHBoxLayout()
@@ -140,24 +158,29 @@ class GuiBuildSettings(NToolDialog):
         self.mainBox.addWidget(self.toolStack)
         self.mainBox.setContentsMargins(0, 0, 0, 0)
 
+        self.bottomBox = QHBoxLayout()
+        self.bottomBox.addWidget(self.lblAutoPreview, 0)
+        self.bottomBox.addWidget(self.swtAutoPreview, 0)
+        self.bottomBox.addSpacing(8)
+        self.bottomBox.addWidget(self.btnBox, 1)
+        self.bottomBox.setContentsMargins(0, 0, 0, 0)
+
         self.outerBox = QVBoxLayout()
         self.outerBox.addLayout(self.topBox)
         self.outerBox.addLayout(self.mainBox)
-        self.outerBox.addWidget(self.buttonBox)
+        self.outerBox.addLayout(self.bottomBox)
         self.outerBox.setSpacing(12)
 
         self.setLayout(self.outerBox)
+        self.updateTheme(init=True)
 
         # Set Default Tab
         self.sidebar.setSelected(self.OPT_FILTERS)
 
         logger.debug("Ready: GuiBuildSettings")
 
-        return
-
     def __del__(self) -> None:  # pragma: no cover
         logger.debug("Delete: GuiBuildSettings")
-        return
 
     def loadContent(self) -> None:
         """Populate the child widgets."""
@@ -165,7 +188,22 @@ class GuiBuildSettings(NToolDialog):
         self.optTabSelect.loadContent()
         self.optTabHeadings.loadContent()
         self.optTabFormatting.loadContent()
-        return
+
+    def updateTheme(self, *, init: bool = False) -> None:
+        """Update theme elements."""
+        logger.debug("Theme Update: GuiBuildSettings, init=%s", init)
+
+        if not init:
+            self.btnApply.updateIcon()
+            self.btnSave.updateIcon()
+            self.btnClose.updateIcon()
+
+            self.optTabSelect.updateTheme()
+            self.optTabHeadings.updateTheme()
+            self.optTabFormatting.updateTheme()
+
+        self.titleLabel.setTextColors(color=SHARED.theme.helpText)
+        self.sidebar.setLabelColor(SHARED.theme.helpText)
 
     ##
     #  Properties
@@ -190,7 +228,6 @@ class GuiBuildSettings(NToolDialog):
         self._saveSettings()
         event.accept()
         self.softDelete()
-        return
 
     ##
     #  Private Slots
@@ -206,23 +243,20 @@ class GuiBuildSettings(NToolDialog):
         elif pageId >= self.OPT_FORMATTING:
             self.toolStack.setCurrentWidget(self.optTabFormatting)
             self.optTabFormatting.scrollToSection(pageId)
-        return
 
     @pyqtSlot("QAbstractButton*")
     def _dialogButtonClicked(self, button: QAbstractButton) -> None:
         """Handle button clicks from the dialog button box."""
-        role = self.buttonBox.buttonRole(button)
-        if role == QtRoleApply:
+        if button == self.btnApply:
             self._applyChanges()
             self._emitBuildData()
-        elif role == QtRoleAccept:
+        elif button == self.btnSave:
             self._applyChanges()
             self._emitBuildData()
             self.close()
-        elif role == QtRoleReject:
+        elif button == self.btnClose:
             self._build.resetChangedState()
             self.close()
-        return
 
     ##
     #  Internal Functions
@@ -238,32 +272,29 @@ class GuiBuildSettings(NToolDialog):
             ).format(self._build.name)):
                 self._emitBuildData()
             self._build.resetChangedState()
-        return
 
     def _saveSettings(self) -> None:
         """Save the various user settings."""
         treeWidth, filterWidth = self.optTabSelect.mainSplitSizes()
         logger.debug("Saving State: GuiBuildSettings")
-        pOptions = SHARED.project.options
-        pOptions.setValue("GuiBuildSettings", "winWidth", self.width())
-        pOptions.setValue("GuiBuildSettings", "winHeight", self.height())
-        pOptions.setValue("GuiBuildSettings", "treeWidth", treeWidth)
-        pOptions.setValue("GuiBuildSettings", "filterWidth", filterWidth)
-        pOptions.saveSettings()
-        return
+        options = SHARED.project.options
+        options.setValue("GuiBuildSettings", "winWidth", self.width())
+        options.setValue("GuiBuildSettings", "winHeight", self.height())
+        options.setValue("GuiBuildSettings", "treeWidth", treeWidth)
+        options.setValue("GuiBuildSettings", "filterWidth", filterWidth)
+        options.setValue("GuiBuildSettings", "autoPreview", self.swtAutoPreview.isChecked())
+        options.saveSettings()
 
     def _applyChanges(self) -> None:
         """Apply all settings changes to the build object."""
         self._build.setName(self.editBuildName.text())
         self.optTabHeadings.saveContent()
         self.optTabFormatting.saveContent()
-        return
 
     def _emitBuildData(self) -> None:
         """Assemble the build data and emit the signal."""
-        self.newSettingsReady.emit(self._build)
+        self.newSettingsReady.emit(self._build, self.swtAutoPreview.isChecked())
         self._build.resetChangedState()
-        return
 
 
 class _FilterTab(NFixedPage):
@@ -289,9 +320,9 @@ class _FilterTab(NFixedPage):
 
         self._statusFlags: dict[int, QIcon] = {
             self.F_NONE:     QIcon(),
-            self.F_FILTERED: SHARED.theme.getIcon("filter", "orange"),
-            self.F_INCLUDED: SHARED.theme.getIcon("pin", "blue"),
-            self.F_EXCLUDED: SHARED.theme.getIcon("exclude", "red"),
+            self.F_FILTERED: SHARED.theme.getIcon("filter", "altaction"),
+            self.F_INCLUDED: SHARED.theme.getIcon("pin", "action"),
+            self.F_EXCLUDED: SHARED.theme.getIcon("exclude", "reject"),
         }
 
         self._trIncluded = self.tr("Included in manuscript")
@@ -330,15 +361,13 @@ class _FilterTab(NFixedPage):
 
         self.includedButton = NIconToolButton(self, iSz)
         self.includedButton.setToolTip(self.tr("Always included"))
-        self.includedButton.setIcon(self._statusFlags[self.F_INCLUDED])
         self.includedButton.clicked.connect(qtLambda(self._setSelectedMode, self.F_INCLUDED))
 
         self.excludedButton = NIconToolButton(self, iSz)
         self.excludedButton.setToolTip(self.tr("Always excluded"))
-        self.excludedButton.setIcon(self._statusFlags[self.F_EXCLUDED])
         self.excludedButton.clicked.connect(qtLambda(self._setSelectedMode, self.F_EXCLUDED))
 
-        self.resetButton = NIconToolButton(self, iSz, "revert", "green")
+        self.resetButton = NIconToolButton(self, iSz)
         self.resetButton.setToolTip(self.tr("Reset to default"))
         self.resetButton.clicked.connect(qtLambda(self._setSelectedMode, self.F_FILTERED))
 
@@ -380,15 +409,13 @@ class _FilterTab(NFixedPage):
             pOptions.getInt("GuiBuildSettings", "filterWidth", 300),
         ])
 
+        self.updateTheme(init=True)
         self.setCentralWidget(self.mainSplit)
 
-        return
-
     def loadContent(self) -> None:
         """Populate the widgets."""
         self._populateTree()
         self._populateFilters()
-        return
 
     def mainSplitSizes(self) -> tuple[int, int]:
         """Extract the sizes of the main splitter."""
@@ -396,6 +423,20 @@ class _FilterTab(NFixedPage):
         m, n = (sizes[0], sizes[1]) if len(sizes) >= 2 else (0, 0)
         return m, n
 
+    def updateTheme(self, *, init: bool = False) -> None:
+        """Update theme elements."""
+        logger.debug("Theme Update: _FilterTab, init=%s", init)
+
+        if not init:
+            self._statusFlags[self.F_FILTERED] = SHARED.theme.getIcon("filter", "altaction")
+            self._statusFlags[self.F_INCLUDED] = SHARED.theme.getIcon("pin", "action")
+            self._statusFlags[self.F_EXCLUDED] = SHARED.theme.getIcon("exclude", "reject")
+            self.loadContent()
+
+        self.includedButton.setIcon(self._statusFlags[self.F_INCLUDED])
+        self.excludedButton.setIcon(self._statusFlags[self.F_EXCLUDED])
+        self.resetButton.setThemeIcon("revert", "reset")
+
     ##
     #  Slots
     ##
@@ -409,7 +450,6 @@ class _FilterTab(NFixedPage):
         elif key.startswith("root:"):
             self._build.setAllowRoot(key[5:], state)
             self._populateTree()
-        return
 
     ##
     #  Internal Functions
@@ -453,8 +493,6 @@ class _FilterTab(NFixedPage):
 
         self._setTreeItemMode()
 
-        return
-
     def _populateFilters(self) -> None:
         """Populate the filter options switches."""
         self.filterOpt.clear()
@@ -472,7 +510,7 @@ class _FilterTab(NFixedPage):
             default=self._build.getBool("filter.includeNotes")
         )
         self.filterOpt.addItem(
-            SHARED.theme.getIcon("unchecked", "red"),
+            SHARED.theme.getIcon("unchecked", "reject"),
             self._build.getLabel("filter.includeInactive"),
             "doc:filter.includeInactive",
             default=self._build.getBool("filter.includeInactive")
@@ -489,8 +527,6 @@ class _FilterTab(NFixedPage):
                     default=self._build.isRootAllowed(tHandle)
                 )
 
-        return
-
     def _setSelectedMode(self, mode: int) -> None:
         """Set the mode for the selected items."""
         items = self.optTree.selectedItems()
@@ -511,8 +547,6 @@ class _FilterTab(NFixedPage):
 
         self._setTreeItemMode()
 
-        return
-
     def _setTreeItemMode(self) -> None:
         """Update the filtered mode icon on all items."""
         filtered = self._build.buildItemFilter(SHARED.project)
@@ -529,11 +563,10 @@ class _FilterTab(NFixedPage):
                 item.setToolTip(self.C_STATUS, self._trIncluded)
             else:
                 item.setIcon(self.C_STATUS, self._statusFlags[self.F_NONE])
-        return
 
     def _scanChildren(self, item: QTreeWidgetItem | None, items: list) -> list[QTreeWidgetItem]:
-        """This is a recursive function returning all items in a tree
-        starting at a given QTreeWidgetItem.
+        """Recursively return all items in a tree starting at a given
+        QTreeWidgetItem.
         """
         if isinstance(item, QTreeWidgetItem):
             items.append(item)
@@ -570,7 +603,7 @@ class _HeadingsTab(NScrollablePage):
         self.lblPart = QLabel(self._build.getLabel("headings.fmtPart"), self)
         self.fmtPart = QLineEdit("", self)
         self.fmtPart.setReadOnly(True)
-        self.btnPart = NIconToolButton(self, iSz, "edit", "green")
+        self.btnPart = NIconToolButton(self, iSz)
         self.btnPart.clicked.connect(qtLambda(self._editHeading, self.EDIT_TITLE))
         self.swtPart = NSwitch(self, height=iPx)
         self.hdePart = QLabel(trHide, self)
@@ -587,7 +620,7 @@ class _HeadingsTab(NScrollablePage):
         self.lblChapter = QLabel(self._build.getLabel("headings.fmtChapter"), self)
         self.fmtChapter = QLineEdit("", self)
         self.fmtChapter.setReadOnly(True)
-        self.btnChapter = NIconToolButton(self, iSz, "edit", "green")
+        self.btnChapter = NIconToolButton(self, iSz)
         self.btnChapter.clicked.connect(qtLambda(self._editHeading, self.EDIT_CHAPTER))
         self.swtChapter = NSwitch(self, height=iPx)
         self.hdeChapter = QLabel(trHide, self)
@@ -604,7 +637,7 @@ class _HeadingsTab(NScrollablePage):
         self.lblUnnumbered = QLabel(self._build.getLabel("headings.fmtUnnumbered"), self)
         self.fmtUnnumbered = QLineEdit("", self)
         self.fmtUnnumbered.setReadOnly(True)
-        self.btnUnnumbered = NIconToolButton(self, iSz, "edit", "green")
+        self.btnUnnumbered = NIconToolButton(self, iSz)
         self.btnUnnumbered.clicked.connect(qtLambda(self._editHeading, self.EDIT_UNNUM))
         self.swtUnnumbered = NSwitch(self, height=iPx)
         self.hdeUnnumbered = QLabel(trHide, self)
@@ -621,7 +654,7 @@ class _HeadingsTab(NScrollablePage):
         self.lblScene = QLabel(self._build.getLabel("headings.fmtScene"), self)
         self.fmtScene = QLineEdit("", self)
         self.fmtScene.setReadOnly(True)
-        self.btnScene = NIconToolButton(self, iSz, "edit", "green")
+        self.btnScene = NIconToolButton(self, iSz)
         self.btnScene.clicked.connect(qtLambda(self._editHeading, self.EDIT_SCENE))
         self.swtScene = NSwitch(self, height=iPx)
         self.hdeScene = QLabel(trHide, self)
@@ -638,7 +671,7 @@ class _HeadingsTab(NScrollablePage):
         self.lblAScene = QLabel(self._build.getLabel("headings.fmtAltScene"), self)
         self.fmtAScene = QLineEdit("", self)
         self.fmtAScene.setReadOnly(True)
-        self.btnAScene = NIconToolButton(self, iSz, "edit", "green")
+        self.btnAScene = NIconToolButton(self, iSz)
         self.btnAScene.clicked.connect(qtLambda(self._editHeading, self.EDIT_HSCENE))
         self.swtAScene = NSwitch(self, height=iPx)
         self.hdeAScene = QLabel(trHide, self)
@@ -655,7 +688,7 @@ class _HeadingsTab(NScrollablePage):
         self.lblSection = QLabel(self._build.getLabel("headings.fmtSection"), self)
         self.fmtSection = QLineEdit("", self)
         self.fmtSection.setReadOnly(True)
-        self.btnSection = NIconToolButton(self, iSz, "edit", "green")
+        self.btnSection = NIconToolButton(self, iSz)
         self.btnSection.clicked.connect(qtLambda(self._editHeading, self.EDIT_SECTION))
         self.swtSection = NSwitch(self, height=iPx)
         self.hdeSection = QLabel(trHide, self)
@@ -789,9 +822,22 @@ class _HeadingsTab(NScrollablePage):
         self.outerBox.addLayout(self.layoutMatrix)
         self.outerBox.addStretch(1)
 
+        self.updateTheme()
         self.setCentralLayout(self.outerBox)
 
-        return
+    def updateTheme(self) -> None:
+        """Update theme elements."""
+        logger.debug("Theme Update: _HeadingsTab")
+
+        self.btnPart.setThemeIcon("edit", "change")
+        self.btnChapter.setThemeIcon("edit", "change")
+        self.btnUnnumbered.setThemeIcon("edit", "change")
+        self.btnScene.setThemeIcon("edit", "change")
+        self.btnAScene.setThemeIcon("edit", "change")
+        self.btnSection.setThemeIcon("edit", "change")
+
+        self.formSyntax.initHighlighter()
+        self.formSyntax.rehighlight()
 
     def loadContent(self) -> None:
         """Populate the widgets."""
@@ -821,7 +867,6 @@ class _HeadingsTab(NScrollablePage):
         self.breakPart.setChecked(self._build.getBool("headings.breakPart"))
         self.breakChapter.setChecked(self._build.getBool("headings.breakChapter"))
         self.breakScene.setChecked(self._build.getBool("headings.breakScene"))
-        return
 
     def saveContent(self) -> None:
         """Save choices back into build object."""
@@ -841,7 +886,6 @@ class _HeadingsTab(NScrollablePage):
         self._build.setValue("headings.breakPart", self.breakPart.isChecked())
         self._build.setValue("headings.breakChapter", self.breakChapter.isChecked())
         self._build.setValue("headings.breakScene", self.breakScene.isChecked())
-        return
 
     ##
     #  Internal Functions
@@ -853,7 +897,6 @@ class _HeadingsTab(NScrollablePage):
             cursor = self.editTextBox.textCursor()
             cursor.insertText(text)
             self.editTextBox.setFocus()
-        return
 
     def _editHeading(self, heading: int) -> None:
         """Populate the form with a specific heading format."""
@@ -886,8 +929,6 @@ class _HeadingsTab(NScrollablePage):
         self.editTextBox.setPlainText(text.replace(nwUnicode.U_LBREAK, "\n"))
         self.lblEditForm.setText(self.tr("Editing: {0}").format(label))
 
-        return
-
     ##
     #  Private Slots
     ##
@@ -929,12 +970,15 @@ class _HeadingSyntaxHighlighter(QSyntaxHighlighter):
 
     def __init__(self, document: QTextDocument | None) -> None:
         super().__init__(document)
-        syntax = SHARED.theme.syntaxTheme
         self._fmtSymbol = QTextCharFormat()
-        self._fmtSymbol.setForeground(syntax.head)
         self._fmtFormat = QTextCharFormat()
+        self.initHighlighter()
+
+    def initHighlighter(self) -> None:
+        """Update theme elements."""
+        syntax = SHARED.theme.syntaxTheme
+        self._fmtSymbol.setForeground(syntax.head)
         self._fmtFormat.setForeground(syntax.emph)
-        return
 
     def highlightBlock(self, text: str) -> None:
         """Add syntax highlighting to the text block."""
@@ -947,7 +991,6 @@ class _HeadingSyntaxHighlighter(QSyntaxHighlighter):
                 ddots = heading.find(":")
                 if ddots > 0:
                     self.setFormat(pos + ddots, 1, self._fmtSymbol)
-        return
 
 
 class _FormattingTab(NScrollableForm):
@@ -960,8 +1003,7 @@ class _FormattingTab(NScrollableForm):
 
         self.setHelpTextStyle(SHARED.theme.helpText)
         self.buildForm()
-
-        return
+        self.updateTheme()
 
     def buildForm(self) -> None:
         """Build the formatting form."""
@@ -1005,7 +1047,7 @@ class _FormattingTab(NScrollableForm):
                 lambda keyword=keyword: self._updateIgnoredKeywords(keyword)
             )
 
-        self.ignoredKeywordsButton = NIconToolButton(self, iSz, "add", "green")
+        self.ignoredKeywordsButton = NIconToolButton(self, iSz)
         self.ignoredKeywordsButton.setMenu(self.mnKeywords)
         self.addRow(
             self._build.getLabel("text.ignoredKeywords"), self.ignoredKeywords,
@@ -1027,7 +1069,7 @@ class _FormattingTab(NScrollableForm):
         # Text Font
         self.textFont = QLineEdit(self)
         self.textFont.setReadOnly(True)
-        self.btnTextFont = NIconToolButton(self, iSz, "font")
+        self.btnTextFont = NIconToolButton(self, iSz)
         self.btnTextFont.clicked.connect(self._selectFont)
         self.addRow(
             self._build.getLabel("format.textFont"), self.textFont,
@@ -1086,12 +1128,12 @@ class _FormattingTab(NScrollableForm):
         self._sidebar.addButton(title, section)
         self.addGroupLabel(title, section)
 
-        pixT = SHARED.theme.getPixmap("margin_top", (iPx, iPx))
-        pixB = SHARED.theme.getPixmap("margin_bottom", (iPx, iPx))
-        pixL = SHARED.theme.getPixmap("margin_left", (iPx, iPx))
-        pixR = SHARED.theme.getPixmap("margin_right", (iPx, iPx))
-        pixH = SHARED.theme.getPixmap("fit_height", (iPx, iPx))
-        pixW = SHARED.theme.getPixmap("fit_width", (iPx, iPx))
+        self.pixT = QLabel(self)
+        self.pixB = QLabel(self)
+        self.pixL = QLabel(self)
+        self.pixR = QLabel(self)
+        self.pixH = QLabel(self)
+        self.pixW = QLabel(self)
 
         # Title
         self.titleMarginT = NDoubleSpinBox(self)
@@ -1102,7 +1144,7 @@ class _FormattingTab(NScrollableForm):
 
         self.addRow(
             self._build.getLabel("format.titleMargin"),
-            [pixT, self.titleMarginT, 6, pixB, self.titleMarginB],
+            [self.pixT, self.titleMarginT, 6, self.pixB, self.titleMarginB],
             unit="em",
         )
 
@@ -1115,7 +1157,7 @@ class _FormattingTab(NScrollableForm):
 
         self.addRow(
             self._build.getLabel("format.h1Margin"),
-            [pixT, self.h1MarginT, 6, pixB, self.h1MarginB],
+            [self.pixT, self.h1MarginT, 6, self.pixB, self.h1MarginB],
             unit="em",
         )
 
@@ -1128,7 +1170,7 @@ class _FormattingTab(NScrollableForm):
 
         self.addRow(
             self._build.getLabel("format.h2Margin"),
-            [pixT, self.h2MarginT, 6, pixB, self.h2MarginB],
+            [self.pixT, self.h2MarginT, 6, self.pixB, self.h2MarginB],
             unit="em",
         )
 
@@ -1141,7 +1183,7 @@ class _FormattingTab(NScrollableForm):
 
         self.addRow(
             self._build.getLabel("format.h3Margin"),
-            [pixT, self.h3MarginT, 6, pixB, self.h3MarginB],
+            [self.pixT, self.h3MarginT, 6, self.pixB, self.h3MarginB],
             unit="em",
         )
 
@@ -1154,7 +1196,7 @@ class _FormattingTab(NScrollableForm):
 
         self.addRow(
             self._build.getLabel("format.h4Margin"),
-            [pixT, self.h4MarginT, 6, pixB, self.h4MarginB],
+            [self.pixT, self.h4MarginT, 6, self.pixB, self.h4MarginB],
             unit="em",
         )
 
@@ -1167,7 +1209,7 @@ class _FormattingTab(NScrollableForm):
 
         self.addRow(
             self._build.getLabel("format.textMargin"),
-            [pixT, self.textMarginT, 6, pixB, self.textMarginB],
+            [self.pixT, self.textMarginT, 6, self.pixB, self.textMarginB],
             unit="em",
         )
 
@@ -1180,7 +1222,7 @@ class _FormattingTab(NScrollableForm):
 
         self.addRow(
             self._build.getLabel("format.sepMargin"),
-            [pixT, self.sepMarginT, 6, pixB, self.sepMarginB],
+            [self.pixT, self.sepMarginT, 6, self.pixB, self.sepMarginB],
             unit="em",
         )
 
@@ -1214,7 +1256,7 @@ class _FormattingTab(NScrollableForm):
 
         self.addRow(
             self._build.getLabel("format.pageSize"),
-            [self.pageSize, 6, pixW, self.pageWidth, 6, pixH, self.pageHeight],
+            [self.pageSize, 6, self.pixW, self.pageWidth, 6, self.pixH, self.pageHeight],
         )
 
         # Page Margins
@@ -1232,11 +1274,11 @@ class _FormattingTab(NScrollableForm):
 
         self.addRow(
             self._build.getLabel("format.pageMargins"),
-            [pixT, self.topMargin, 6, pixB, self.bottomMargin],
+            [self.pixT, self.topMargin, 6, self.pixB, self.bottomMargin],
         )
         self.addRow(
             "",
-            [pixL, self.leftMargin, 6, pixR, self.rightMargin],
+            [self.pixL, self.leftMargin, 6, self.pixR, self.rightMargin],
         )
 
         # Open Document
@@ -1248,21 +1290,21 @@ class _FormattingTab(NScrollableForm):
         self.addGroupLabel(title, section)
 
         # Header
-        self.odtPageHeader = QLineEdit(self)
-        self.odtPageHeader.setMinimumWidth(200)
-        self.btnPageHeader = NIconToolButton(self, iSz, "revert", "green")
+        self.pageHeader = QLineEdit(self)
+        self.pageHeader.setMinimumWidth(200)
+        self.btnPageHeader = NIconToolButton(self, iSz)
         self.btnPageHeader.clicked.connect(self._resetPageHeader)
         self.addRow(
-            self._build.getLabel("doc.pageHeader"), self.odtPageHeader,
+            self._build.getLabel("doc.pageHeader"), self.pageHeader,
             button=self.btnPageHeader, stretch=(1, 1)
         )
 
-        self.odtPageCountOffset = NSpinBox(self)
-        self.odtPageCountOffset.setMinimum(0)
-        self.odtPageCountOffset.setMaximum(999)
-        self.odtPageCountOffset.setSingleStep(1)
-        self.odtPageCountOffset.setMinimumWidth(spW)
-        self.addRow(self._build.getLabel("doc.pageCountOffset"), self.odtPageCountOffset)
+        self.pageCountOffset = NSpinBox(self)
+        self.pageCountOffset.setMinimum(0)
+        self.pageCountOffset.setMaximum(999)
+        self.pageCountOffset.setSingleStep(1)
+        self.pageCountOffset.setMinimumWidth(spW)
+        self.addRow(self._build.getLabel("doc.pageCountOffset"), self.pageCountOffset)
 
         # Headings
         self.colorHeadings = NSwitch(self, height=iPx)
@@ -1273,6 +1315,20 @@ class _FormattingTab(NScrollableForm):
         self.addRow(self._build.getLabel("doc.scaleHeadings"), self.scaleHeadings)
         self.addRow(self._build.getLabel("doc.boldHeadings"), self.boldHeadings)
 
+        # Meta Language
+        self.lblMetaLanguage = QLabel(self)
+        self.lblMetaLanguage.setAlignment(QtAlignRightMiddle)
+        self.lblMetaLanguage.setFixedWidth(200)
+
+        self.metaLanguage = QLineEdit(self)
+        self.metaLanguage.setAlignment(QtAlignCenter)
+        self.metaLanguage.setFixedWidth(80)
+        self.metaLanguage.textChanged.connect(self._refreshMetaLang)
+
+        self.addRow(
+            self._build.getLabel("doc.metaLanguage"), [self.lblMetaLanguage, 8, self.metaLanguage]
+        )
+
         # HTML Document
         # =============
 
@@ -1290,7 +1346,24 @@ class _FormattingTab(NScrollableForm):
         # Finalise
         self.finalise()
 
-        return
+    def updateTheme(self) -> None:
+        """Update theme elements."""
+        logger.debug("Theme Update: _FormattingTab")
+
+        self.ignoredKeywordsButton.setThemeIcon("add", "add")
+        self.btnTextFont.setThemeIcon("font", "tool")
+        self.btnPageHeader.setThemeIcon("revert", "reset")
+
+        iPx = SHARED.theme.baseIconHeight
+        self.pixT.setPixmap(SHARED.theme.getPixmap("margin_top", (iPx, iPx)))
+        self.pixB.setPixmap(SHARED.theme.getPixmap("margin_bottom", (iPx, iPx)))
+        self.pixL.setPixmap(SHARED.theme.getPixmap("margin_left", (iPx, iPx)))
+        self.pixR.setPixmap(SHARED.theme.getPixmap("margin_right", (iPx, iPx)))
+        self.pixH.setPixmap(SHARED.theme.getPixmap("fit_height", (iPx, iPx)))
+        self.pixW.setPixmap(SHARED.theme.getPixmap("fit_width", (iPx, iPx)))
+
+        self.pageSize.updateStyle()
+        self.pageUnit.updateStyle()
 
     def loadContent(self) -> None:
         """Populate the widgets."""
@@ -1381,9 +1454,10 @@ class _FormattingTab(NScrollableForm):
         self.colorHeadings.setChecked(self._build.getBool("doc.colorHeadings"))
         self.scaleHeadings.setChecked(self._build.getBool("doc.scaleHeadings"))
         self.boldHeadings.setChecked(self._build.getBool("doc.boldHeadings"))
-        self.odtPageHeader.setText(self._build.getStr("doc.pageHeader"))
-        self.odtPageCountOffset.setValue(self._build.getInt("doc.pageCountOffset"))
-        self.odtPageHeader.setCursorPosition(0)
+        self.metaLanguage.setText(processLangCode(self._build.getStr("doc.metaLanguage")))
+        self.pageHeader.setText(self._build.getStr("doc.pageHeader"))
+        self.pageCountOffset.setValue(self._build.getInt("doc.pageCountOffset"))
+        self.pageHeader.setCursorPosition(0)
 
         # HTML Document
         # =============
@@ -1391,8 +1465,6 @@ class _FormattingTab(NScrollableForm):
         self.htmlAddStyles.setChecked(self._build.getBool("html.addStyles"))
         self.htmlPreserveTabs.setChecked(self._build.getBool("html.preserveTabs"))
 
-        return
-
     def saveContent(self) -> None:
         """Save choices back into build object."""
         # Text Content
@@ -1448,18 +1520,21 @@ class _FormattingTab(NScrollableForm):
         self._build.setValue("format.rightMargin", self.rightMargin.value())
 
         # Documents
+        metaLanguage = processLangCode(self.metaLanguage.text())
+
         self._build.setValue("doc.colorHeadings", self.colorHeadings.isChecked())
         self._build.setValue("doc.scaleHeadings", self.scaleHeadings.isChecked())
         self._build.setValue("doc.boldHeadings", self.boldHeadings.isChecked())
-        self._build.setValue("doc.pageHeader", self.odtPageHeader.text())
-        self._build.setValue("doc.pageCountOffset", self.odtPageCountOffset.value())
+        self._build.setValue("doc.metaLanguage", metaLanguage)
+        self._build.setValue("doc.pageHeader", self.pageHeader.text())
+        self._build.setValue("doc.pageCountOffset", self.pageCountOffset.value())
+
+        self.metaLanguage.setText(metaLanguage)
 
         # HTML Document
         self._build.setValue("html.addStyles", self.htmlAddStyles.isChecked())
         self._build.setValue("html.preserveTabs", self.htmlPreserveTabs.isChecked())
 
-        return
-
     ##
     #  Private Slots
     ##
@@ -1472,11 +1547,10 @@ class _FormattingTab(NScrollableForm):
             self._textFont = fontMatcher(font)
             self.textFont.setText(describeFont(self._textFont))
             self.textFont.setCursorPosition(0)
-        return
 
     @pyqtSlot(int)
     def _changeUnit(self, index: int) -> None:
-        """The current unit change, so recalculate sizes."""
+        """Process current unit change to recalculate sizes."""
         newUnit = self.pageUnit.itemData(index)
         newScale = nwLabels.UNIT_SCALE.get(newUnit, 1.0)
         reScale = self._unitScale/newScale
@@ -1531,11 +1605,9 @@ class _FormattingTab(NScrollableForm):
         self._unitScale = newScale
         self._changePageSize(self.pageSize.currentIndex())
 
-        return
-
     @pyqtSlot(int)
     def _changePageSize(self, index: int) -> None:
-        """The page size has changed."""
+        """Process page size change."""
         w, h = nwLabels.PAPER_SIZE[self.pageSize.itemData(index)] if index >= 0 else (-1.0, -1.0)
         if w > 0.0 and h > 0.0:
             self.pageWidth.blockSignals(True)
@@ -1544,23 +1616,27 @@ class _FormattingTab(NScrollableForm):
             self.pageHeight.blockSignals(True)
             self.pageHeight.setValue(h/self._unitScale)
             self.pageHeight.blockSignals(False)
-        return
 
     @pyqtSlot()
     def _pageSizeValueChanged(self) -> None:
-        """The user has changed the page size spin boxes, so we flip
-        the page size box to Custom.
+        """Process that the user has changed the page size spin boxes,
+        so we flip the page size box to Custom.
         """
         index = self.pageSize.findData("Custom")
         if index >= 0:
             self.pageSize.setCurrentIndex(index)
-        return
 
+    @pyqtSlot()
     def _resetPageHeader(self) -> None:
-        """Reset the ODT header format to default."""
-        self.odtPageHeader.setText(nwHeadFmt.DOC_AUTO)
-        self.odtPageHeader.setCursorPosition(0)
-        return
+        """Reset the document header format to default."""
+        self.pageHeader.setText(nwHeadFmt.DOC_AUTO)
+        self.pageHeader.setCursorPosition(0)
+
+    @pyqtSlot()
+    def _refreshMetaLang(self) -> None:
+        """Update the meta language helper info."""
+        code = self.metaLanguage.text().strip()
+        self.lblMetaLanguage.setText(languageName(code))
 
     ##
     #  Internal Functions
@@ -1573,4 +1649,3 @@ class _FormattingTab(NScrollableForm):
             current.append(keyword)
         verified = set(x for x in current if x in nwKeyWords.VALID_KEYS)
         self.ignoredKeywords.setText(", ".join(verified))
-        return
